-- add posts column in user table
ALTER TABLE wcf1_user ADD wbbPosts INT(10) NOT NULL DEFAULT 0;
ALTER TABLE wcf1_user ADD INDEX wbbPosts (wbbPosts);

DROP TABLE IF EXISTS wbb1_board;
CREATE TABLE wbb1_board (
	-- general
	boardID INT(10) NOT NULL AUTO_INCREMENT PRIMARY KEY,
	parentID INT(10),
	position SMALLINT(5) NOT NULL DEFAULT 0,
	boardType TINYINT(1) NOT NULL DEFAULT 0,
	title VARCHAR(255) NOT NULL DEFAULT '',
	description MEDIUMTEXT,
	descriptionUseHtml TINYINT(1) NOT NULL DEFAULT 0,
	externalURL VARCHAR(255) NOT NULL DEFAULT '',
	time INT(10) NOT NULL DEFAULT 0,
	
	-- properties
	countUserPosts TINYINT(1) NOT NULL DEFAULT 1,
	daysPrune SMALLINT(5) NOT NULL DEFAULT 0,
	enableMarkingAsDone TINYINT(1) NOT NULL DEFAULT 0,
	ignorable TINYINT(1) NOT NULL DEFAULT 1,
	isClosed TINYINT(1) NOT NULL DEFAULT 0,
	isInvisible TINYINT(1) NOT NULL DEFAULT 0,
	postSortOrder VARCHAR(4) NOT NULL DEFAULT '',
	postsPerPage SMALLINT(5) NOT NULL DEFAULT 0,
	searchable TINYINT(1) NOT NULL DEFAULT 1,
	searchableForSimilarThreads TINYINT(1) NOT NULL DEFAULT 1,
	showSubBoards TINYINT(1) NOT NULL DEFAULT 1,
	sortField VARCHAR(20) NOT NULL DEFAULT '',
	sortOrder VARCHAR(4) NOT NULL DEFAULT '',
	styleID INT(10),
	threadsPerPage SMALLINT(5) NOT NULL DEFAULT 0,
	
	-- statistics
	clicks INT(10) NOT NULL DEFAULT 0,
	posts INT(10) NOT NULL DEFAULT 0,
	threads INT(10) NOT NULL DEFAULT 0,
	
	UNIQUE KEY (parentID, boardID)
);

DROP TABLE IF EXISTS wbb1_board_last_post;
CREATE TABLE wbb1_board_last_post (
	boardID INT(10) NOT NULL,
	languageID INT(10),
	threadID INT(10) NOT NULL,
	UNIQUE KEY (boardID, languageID)
);

DROP TABLE IF EXISTS wbb1_post;
CREATE TABLE wbb1_post (
	postID INT(10) NOT NULL AUTO_INCREMENT PRIMARY KEY,
	threadID INT(10) NOT NULL,
	userID INT(10),
	username VARCHAR(255) NOT NULL DEFAULT '',
	subject VARCHAR(255) NOT NULL DEFAULT '',
	message MEDIUMTEXT NOT NULL,
	time INT(10) NOT NULL DEFAULT 0,
	
	isDeleted TINYINT(1) NOT NULL DEFAULT 0,
	isDisabled TINYINT(1) NOT NULL DEFAULT 0,
	isClosed TINYINT(1) NOT NULL DEFAULT 0,
	editorID INT(10),
	editor VARCHAR(255) NOT NULL DEFAULT '',
	lastEditTime INT(10) NOT NULL DEFAULT 0,
	editCount MEDIUMINT(7) NOT NULL DEFAULT 0,
	editReason TEXT,
	attachments SMALLINT(5) NOT NULL DEFAULT 0,
	pollID INT(10),
	enableSmilies TINYINT(1) NOT NULL DEFAULT 1,
	enableHtml TINYINT(1) NOT NULL DEFAULT 0,
	enableBBCodes TINYINT(1) NOT NULL DEFAULT 1,
	showSignature TINYINT(1) NOT NULL DEFAULT 1,
	ipAddress VARCHAR(39) NOT NULL DEFAULT '',
	cumulativeLikes MEDIUMINT(7) NOT NULL DEFAULT 0,
	deleteTime INT(10) NOT NULL DEFAULT 0,
	KEY (threadID, userID),
	KEY threadID_2 (threadID, isDeleted, isDisabled, time),
	KEY (isDeleted),
	KEY (isDisabled),
	KEY (ipAddress),
	KEY (time)
);

DROP TABLE IF EXISTS wbb1_thread;
CREATE TABLE wbb1_thread (
	threadID INT(10) NOT NULL AUTO_INCREMENT PRIMARY KEY,
	boardID INT(10) NOT NULL,
	languageID INT(10),
	topic VARCHAR(255) NOT NULL DEFAULT '',
	firstPostID INT(10),
	time INT(10) NOT NULL DEFAULT 0,
	userID INT(10),
	username VARCHAR(255) NOT NULL DEFAULT '',
	lastPostID INT(10),
	lastPostTime INT(10) NOT NULL DEFAULT 0,
	lastPosterID INT(10),
	lastPoster VARCHAR(255) NOT NULL DEFAULT '',
	replies MEDIUMINT(7) NOT NULL DEFAULT 0,
	views MEDIUMINT(7) NOT NULL DEFAULT 0,
	attachments SMALLINT(5) NOT NULL DEFAULT 0,
	polls SMALLINT(5) NOT NULL DEFAULT 0,
	isAnnouncement TINYINT(1) NOT NULL DEFAULT 0,
	isSticky TINYINT(1) NOT NULL DEFAULT 0,
	isDisabled TINYINT(1) NOT NULL DEFAULT 0,
	isClosed TINYINT(1) NOT NULL DEFAULT 0,
	isDeleted TINYINT(1) NOT NULL DEFAULT 0,
	movedThreadID INT(10),
	movedTime INT(10) NOT NULL DEFAULT 0,
	isDone TINYINT(1) NOT NULL DEFAULT 0,
	cumulativeLikes MEDIUMINT(7) NOT NULL DEFAULT 0,
	hasLabels TINYINT(1) NOT NULL DEFAULT 0,
	deleteTime INT(10) NOT NULL DEFAULT 0,
	KEY (lastPostTime),
	KEY (boardID, isAnnouncement, isSticky, lastPostTime, isDeleted, isDisabled),
	KEY (boardID, isDeleted, isDisabled, movedThreadID),
	KEY (isDeleted),
	KEY (isDisabled),
	KEY (movedTime)
);

DROP TABLE IF EXISTS wbb1_thread_announcement;
CREATE TABLE wbb1_thread_announcement (
	boardID INT(10) NOT NULL,
	threadID INT(10) NOT NULL,
	PRIMARY KEY (boardID, threadID)
);

DROP TABLE IF EXISTS wbb1_thread_similar;
CREATE TABLE wbb1_thread_similar (
	threadID INT(10) NOT NULL,
	similarThreadID INT(10) NOT NULL,
	UNIQUE KEY (threadID, similarThreadID)
);


ALTER TABLE wbb1_board ADD FOREIGN KEY (styleID) REFERENCES wcf1_style (styleID) ON DELETE SET NULL;
ALTER TABLE wbb1_board ADD FOREIGN KEY (parentID) REFERENCES wbb1_board (boardID) ON DELETE SET NULL;

ALTER TABLE wbb1_board_last_post ADD FOREIGN KEY (boardID) REFERENCES wbb1_board (boardID) ON DELETE CASCADE;
ALTER TABLE wbb1_board_last_post ADD FOREIGN KEY (languageID) REFERENCES wcf1_language (languageID) ON DELETE CASCADE;
ALTER TABLE wbb1_board_last_post ADD FOREIGN KEY (threadID) REFERENCES wbb1_thread (threadID) ON DELETE CASCADE;

ALTER TABLE wbb1_post ADD FOREIGN KEY (threadID) REFERENCES wbb1_thread (threadID) ON DELETE CASCADE;
ALTER TABLE wbb1_post ADD FOREIGN KEY (userID) REFERENCES wcf1_user (userID) ON DELETE SET NULL;
ALTER TABLE wbb1_post ADD FOREIGN KEY (editorID) REFERENCES wcf1_user (userID) ON DELETE SET NULL;
ALTER TABLE wbb1_post ADD FOREIGN KEY (pollID) REFERENCES wcf1_poll (pollID) ON DELETE SET NULL;

ALTER TABLE wbb1_thread ADD FOREIGN KEY (boardID) REFERENCES wbb1_board (boardID) ON DELETE CASCADE;
ALTER TABLE wbb1_thread ADD FOREIGN KEY (languageID) REFERENCES wcf1_language (languageID) ON DELETE SET NULL;
ALTER TABLE wbb1_thread ADD FOREIGN KEY (userID) REFERENCES wcf1_user (userID) ON DELETE SET NULL;
ALTER TABLE wbb1_thread ADD FOREIGN KEY (lastPosterID) REFERENCES wcf1_user (userID) ON DELETE SET NULL;
ALTER TABLE wbb1_thread ADD FOREIGN KEY (movedThreadID) REFERENCES wbb1_thread (threadID) ON DELETE CASCADE;

ALTER TABLE wbb1_thread_announcement ADD FOREIGN KEY (boardID) REFERENCES wbb1_board (boardID) ON DELETE CASCADE;
ALTER TABLE wbb1_thread_announcement ADD FOREIGN KEY (threadID) REFERENCES wbb1_thread (threadID) ON DELETE CASCADE;

ALTER TABLE wbb1_thread_similar ADD FOREIGN KEY (threadID) REFERENCES wbb1_thread (threadID) ON DELETE CASCADE;
ALTER TABLE wbb1_thread_similar ADD FOREIGN KEY (similarThreadID) REFERENCES wbb1_thread (threadID) ON DELETE CASCADE;


--- default values
INSERT INTO	wbb1_board
		(boardID, boardType, title)
VALUES		(1, 1, 'Main Category');
INSERT INTO	wbb1_board
		(boardID, parentID, title, description)
VALUES		(2, 1, 'Default Forum', 'This is the description of the default forum.');
