<?php
namespace wbb\acp\form;
use wbb\data\board\Board;
use wbb\data\board\BoardAction;
use wbb\data\board\BoardCache;
use wbb\data\board\RealtimeBoardNodeList;
use wcf\data\package\PackageCache;
use wcf\form\AbstractForm;
use wcf\system\acl\ACLHandler;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\exception\UserInputException;
use wcf\system\language\I18nHandler;
use wcf\system\user\storage\UserStorageHandler;
use wcf\system\WCF;

/**
 * Shows the board edit form.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	acp.form
 * @category	Burning Board
 */
class BoardEditForm extends BoardAddForm {
	/**
	 * @see	wcf\page\AbstractPage::$activeMenuItem
	 */
	public $templateName = 'boardAdd';
	
	/**
	 * @see	wcf\page\AbstractPage::$activeMenuItem
	 */
	public $activeMenuItem = 'wbb.acp.menu.link.board';
	
	/**
	 * @see	wcf\page\AbstractPage::$neededPermissions
	 */
	public $neededPermissions = array('admin.board.canEditBoard');
	
	/**
	 * id of the edited board
	 * @var	integer
	 */
	public $boardID = 0;
	
	/**
	 * edited board object
	 * @var	wbb\data\board\Board
	 */
	public $board = null;
	
	/**
	 * @see	wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['id'])) $this->boardID = intval($_REQUEST['id']);
		$this->board = new Board($this->boardID);
		if (!$this->board->boardID) {
			throw new PermissionDeniedException();
		}
	}
	
	/**
	 * @see wbb\acp\form\BoardAddForm::validateParentID()
	 */
	protected function validateParentID() {
		parent::validateParentID();
		
		if ($this->parentID) {
			if ($this->boardID == $this->parentID) {
				throw new UserInputException('parentID', 'notValid');
			}
			
			$board = BoardCache::getInstance()->getBoard($this->parentID);
			while ($board->parentID != null) {
				$board = BoardCache::getInstance()->getBoard($board->parentID);
				if ($board->boardID == $this->boardID) {
					throw new UserInputException('parentID', 'notValid');
				}
			}
		}
	}
	
	/**
	 * @see	wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		if (empty($_POST)) {
			I18nHandler::getInstance()->setOptions('description', PackageCache::getInstance()->getPackageID('com.woltlab.wbb'), $this->board->description, 'wbb.board.board\d+.description');
			I18nHandler::getInstance()->setOptions('title', PackageCache::getInstance()->getPackageID('com.woltlab.wbb'), $this->board->title, 'wbb.board.board\d+');
			
			$this->boardType = $this->board->boardType;
			$this->countUserPosts = $this->board->countUserPosts;
			$this->daysPrune = $this->board->daysPrune;
			$this->description = $this->board->description;
			$this->descriptionUseHtml = $this->board->descriptionUseHtml;
			$this->enableMarkingAsDone = $this->board->enableMarkingAsDone;
			$this->ignorable = $this->board->ignorable;
			$this->isClosed = $this->board->isClosed;
			$this->isInvisible = $this->board->isInvisible;
			$this->parentID = $this->board->parentID;
			$this->position = $this->board->position;
			$this->postSortOrder = $this->board->postSortOrder;
			$this->postsPerPage = $this->board->postsPerPage;
			$this->searchable = $this->board->searchable;
			$this->searchableForSimilarThreads = $this->board->searchableForSimilarThreads;
			$this->showSubBoards = $this->board->showSubBoards;
			$this->sortField = $this->board->sortField;
			$this->sortOrder = $this->board->sortOrder;
			$this->threadsPerPage = $this->board->threadsPerPage;
			$this->title = $this->board->title;
			$this->styleID = $this->board->styleID;
			$this->externalURL = $this->board->externalURL;
		}
	}
	
	/**
	 * @see	wcf\form\IForm::save()
	 */
	public function save() {
		AbstractForm::save();
		
		// update description
		$this->description = 'wbb.board.board'.$this->board->boardID.'.description';
		if (I18nHandler::getInstance()->isPlainValue('description')) {
			I18nHandler::getInstance()->remove($this->description);
			$this->description = I18nHandler::getInstance()->getValue('description');
		}
		else {
			I18nHandler::getInstance()->save('description', $this->description, 'wbb.board', PackageCache::getInstance()->getPackageID('com.woltlab.wbb'));
		}
		
		// update title
		$this->title = 'wbb.board.board'.$this->board->boardID;
		if (I18nHandler::getInstance()->isPlainValue('title')) {
			I18nHandler::getInstance()->remove($this->title);
			$this->title = I18nHandler::getInstance()->getValue('title');
		}
		else {
			I18nHandler::getInstance()->save('title', $this->title, 'wbb.board', PackageCache::getInstance()->getPackageID('com.woltlab.wbb'));
		}
		
		// update board
		$this->objectAction = new BoardAction(array($this->board), 'update', array('data' => array(
			'boardType' => $this->boardType,
			'countUserPosts' => ($this->countUserPosts ? 1 : 0),
			'daysPrune' => $this->daysPrune,
			'description' => $this->description,
			'descriptionUseHtml' => ($this->descriptionUseHtml ? 1 : 0),
			'enableMarkingAsDone' => ($this->enableMarkingAsDone ? 1 : 0),
			'ignorable' => ($this->ignorable ? 1 : 0),
			'isClosed' => ($this->isClosed ? 1 : 0),
			'isInvisible' => ($this->isInvisible ? 1 : 0),
			'parentID' => ($this->parentID ?: null),
			'position' => $this->position,
			'postSortOrder' => $this->postSortOrder,
			'postsPerPage' => $this->postsPerPage,
			'searchable' => ($this->searchable ? 1 : 0),
			'searchableForSimilarThreads' => ($this->searchableForSimilarThreads ? 1 : 0),
			'showSubBoards' => ($this->showSubBoards ? 1 : 0),
			'sortField' => $this->sortField,
			'sortOrder' => $this->sortOrder,
			'threadsPerPage' => $this->threadsPerPage,
			'title' => $this->title,
			'externalURL' => $this->externalURL,
			'styleID' => ($this->styleID ?: null)
		)));
		$this->objectAction->executeAction();
		
		// save ACL
		ACLHandler::getInstance()->save($this->board->boardID, $this->objectTypeID);
		ACLHandler::getInstance()->disableAssignVariables();
		UserStorageHandler::getInstance()->resetAll('wbbBoardPermissions');
		$this->saved();
		
		// show success
		WCF::getTPL()->assign(array(
			'success' => true
		));
	}
	
	/**
	 * @see	wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		$useRequestData = (empty($_POST)) ? false : true;
		I18nHandler::getInstance()->assignVariables($useRequestData);
		
		$availableBoards = new RealtimeBoardNodeList();
		$availableBoards->readNodeTree();
		WCF::getTPL()->assign(array(
			'action' => 'edit',
			'boardID' => $this->boardID,
			'availableBoards' => $availableBoards->getNodeList()
		));
	}
}
