<?php
namespace wbb\data\board;

/**
 * Represents an uncached board list.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.board
 * @category	Burning Board
 */
class RealtimeBoardNodeList extends BoardNodeList {
	/**
	 * list of boards
	 * @var	array<wbb\data\board\Board>
	 */
	public $boards = array();
	
	/**
	 * board structure
	 * @var	array<array>
	 */
	public $boardStructure = array();
	
	/**
	 * @see	wbb\data\board\BoardNodeTree::__construct()
	 */
	public function __construct($parentID = null, $startDepth = 0, array $filter = array()) {
		parent::__construct($parentID, $startDepth, $filter);
		
		$boardList = new BoardList();
		$boardList->sqlOrderBy = "board.parentID ASC, board.position ASC";
		$boardList->readObjects();
		
		foreach ($boardList as $board) {
			$this->boards[$board->boardID] = $board;
			
			if (!isset($this->boardStructure[$board->parentID])) {
				$this->boardStructure[$board->parentID] = array();
			}
			$this->boardStructure[$board->parentID][] = $board->boardID;
		}
	}
	
	/**
	 * @see	wbb\data\board\BoardNodeTree::generateNodeTree()
	 */
	protected function generateNodeTree($parentID, BoardNode $parentNode = null, array $filter = array()) {
		$nodes = array();
		
		// apply filter
		$boardIDs = $this->getChildIDs($parentID);
		if (count($filter)) $boardIDs = array_intersect($boardIDs, $filter);
		
		foreach ($boardIDs as $boardID) {
			$board = $this->getBoard($boardID);
			if ($this->isVisible($board)) {
				$node = new $this->nodeClassname($parentNode, $board, ($parentNode !== null ? ($parentNode->getDepth() + 1) : 0));
				$nodes[] = $node;
				
				// get children
				$node->setChildren($this->generateNodeTree($boardID, $node));
			}
		}
		
		return $nodes;
	}
	
	/**
	 * Returns a list of child board ids.
	 * 
	 * @param	integer		$boardID
	 * @return	array<integer>
	 */
	protected function getChildIDs($parentID) {
		return (isset($this->boardStructure[$parentID]) ? $this->boardStructure[$parentID] : array());
	}
	
	/**
	 * Returns a board by id.
	 * 
	 * @param	integer			$boardID
	 * @return	wbb\data\board\Board
	 */
	protected function getBoard($boardID) {
		return $this->boards[$boardID];
	}
}
