<?php
namespace wbb\data\modification\log;
use wbb\data\post\PostList;
use wbb\data\thread\Thread;
use wbb\system\log\modification\ThreadModificationLogHandler;
use wcf\data\modification\log\ModificationLogList;
use wcf\system\WCF;

/**
 * Represents a list of modification logs for thread log page.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.modification.log
 * @category	Burning Board
 */
class ThreadLogModificationLogList extends ModificationLogList {
	/**
	 * post object type id
	 * @var	integer
	 */
	public $postObjectTypeID = 0;
	
	/**
	 * thread object type id
	 * @var	integer
	 */
	public $threadObjectTypeID = 0;
	
	/**
	 * thread object
	 * @var	wbb\data\thread\Thread
	 */
	public $thread = null;
	
	/**
	 * @see	wbb\data\DatabaseObjectList::__construct()
	 */
	public function __construct() {
		parent::__construct();
		
		// get object types
		$postObjectType = ThreadModificationLogHandler::getInstance()->getObjectType('com.woltlab.wbb.post');
		$this->postObjectTypeID = $postObjectType->objectTypeID;
		$threadObjectType = ThreadModificationLogHandler::getInstance()->getObjectType('com.woltlab.wbb.thread');
		$this->threadObjectTypeID = $threadObjectType->objectTypeID;
	}
	
	/**
	 * Initializes the thread log modification log list.
	 * 
	 * @param	wbb\data\thread\Thread	$thread
	 */
	public function setThread(Thread $thread) {
		$this->thread = $thread;
	}
	
	/**
	 * @see	wcf\data\DatabaseObjectList::countObjects()
	 */
	public function countObjects() {
		$sql = "SELECT		COUNT(modification_log.logID) AS count
			FROM		wcf".WCF_N."_modification_log modification_log
			WHERE		modification_log.objectTypeID = ?
					AND modification_log.objectID = ?
			UNION SELECT	COUNT(modification_log.logID) AS count
			FROM		wcf".WCF_N."_modification_log modification_log
			LEFT JOIN	wbb".WCF_N."_post post
			ON		(post.postID = modification_log.objectID AND post.threadID = ?)
			WHERE		modification_log.objectTypeID = ?
					AND modification_log.objectID = post.postID";
		$statement = WCF::getDB()->prepareStatement($sql);
		$statement->execute(array(
			$this->threadObjectTypeID,
			$this->thread->threadID,
			$this->thread->threadID,
			$this->postObjectTypeID
		));
		$count = 0;
		while ($row = $statement->fetchArray()) {
			$count += $row['count'];
		}
		
		return $count;
	}
	
	/**
	 * @see	wcf\data\DatabaseObjectList::readObjects()
	 */
	public function readObjects() {
		$sql = "SELECT		user_avatar.*, user_table.email, user_table.disableAvatar, user_table.enableGravatar,
					modification_log.*
			FROM		wcf".WCF_N."_modification_log modification_log
			LEFT JOIN	wcf".WCF_N."_user user_table
			ON		(user_table.userID = modification_log.userID)
			LEFT JOIN	wcf".WCF_N."_user_avatar user_avatar
			ON		(user_avatar.avatarID = user_table.avatarID)
			WHERE		modification_log.objectTypeID = ?
					AND modification_log.objectID = ?
			UNION
			SELECT		user_avatar.*, user_table.email, user_table.disableAvatar, user_table.enableGravatar,
					modification_log.*
			FROM		wcf".WCF_N."_modification_log modification_log
			LEFT JOIN	wbb".WCF_N."_post post
			ON		(post.postID = modification_log.objectID AND post.threadID = ?)
			LEFT JOIN	wcf".WCF_N."_user user_table
			ON		(user_table.userID = modification_log.userID)
			LEFT JOIN	wcf".WCF_N."_user_avatar user_avatar
			ON		(user_avatar.avatarID = user_table.avatarID)
			WHERE		modification_log.objectTypeID = ?
					AND modification_log.objectID = post.postID
			".(!empty($this->sqlOrderBy) ? "ORDER BY ".$this->sqlOrderBy : '');
		$statement = WCF::getDB()->prepareStatement($sql, $this->sqlLimit, $this->sqlOffset);
		$statement->execute(array(
			$this->threadObjectTypeID,
			$this->thread->threadID,
			$this->thread->threadID,
			$this->postObjectTypeID
		));
		$this->objects = $statement->fetchObjects(($this->objectClassName ?: $this->className));
		
		// use table index as array index
		$objects = array();
		foreach ($this->objects as $object) {
			$objectID = $object->{$this->getDatabaseTableIndexName()};
			$objects[$objectID] = $object;
			
			$this->indexToObject[] = $objectID;
		}
		$this->objectIDs = $this->indexToObject;
		$this->objects = $objects;
		
		$postIDs = array();
		foreach ($this->objects as &$object) {
			if ($object->objectTypeID == $this->postObjectTypeID) {
				$object = new ViewablePostModificationLog($object);
				$postIDs[] = $object->objectID;
			}
			else {
				$object = new ViewableThreadModificationLog($object);
			}
		}
		unset($object);
		
		if (!empty($postIDs)) {
			$postList = new PostList();
			$postList->getConditionBuilder()->add("post.postID IN (?)", array($postIDs));
			$postList->readObjects();
			
			foreach ($this->objects as $object) {
				if ($object instanceof ViewablePostModificationLog) {
					foreach ($postList as $post) {
						if ($object->objectID == $post->postID) {
							$object->setPost($post);
							break;
						}
					}
				}
			}
		}
	}
}
