<?php
namespace wbb\data\modification\log;
use wbb\system\log\modification\ThreadModificationLogHandler;
use wcf\data\modification\log\ModificationLogList;

/**
 * Represents a list of modification logs for thread page.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.modification.log
 * @category	Burning Board
 */
class ThreadModificationLogList extends ModificationLogList {
	/**
	 * Creates a new ThreadModificationLogList object.
	 */
	public function __construct() {
		parent::__construct();
		
		// get avatars
		if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
		$this->sqlSelects .= "user_avatar.*, user_table.email, user_table.disableAvatar, user_table.enableGravatar";
		$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_user user_table ON (user_table.userID = modification_log.userID)";
		$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_user_avatar user_avatar ON (user_avatar.avatarID = user_table.avatarID)";
	}
	
	/**
	 * Initializes the board modification log list.
	 * 
	 * @param	array<integer>	$postIDs
	 * @param	string		$action
	 */
	public function setPostData(array $postIDs, $action = '') {
		// load object type id
		$objectType = ThreadModificationLogHandler::getInstance()->getObjectType('com.woltlab.wbb.post');
		
		// add conditions
		$this->getConditionBuilder()->add("objectTypeID = ?", array($objectType->objectTypeID));
		$this->getConditionBuilder()->add("objectID IN (?)", array($postIDs));
		if (!empty($action)) $this->getConditionBuilder()->add("action = ?", array($action));
	}
	
	/**
	 * @see	wcf\data\DatabaseObjectList::readObjects()
	 */
	public function readObjects() {
		parent::readObjects();
		
		foreach ($this->objects as &$object) {
			$object = new ViewablePostModificationLog($object);
		}
		unset($object);
	}
}
