<?php
namespace wbb\data\modification\log;
use wbb\data\post\Post;
use wcf\data\user\UserProfile;
use wcf\data\user\User;
use wcf\data\DatabaseObjectDecorator;
use wcf\system\WCF;

/**
 * Provides a viewable post modification log.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.modification.log
 * @category	Burning Board
 */
class ViewablePostModificationLog extends DatabaseObjectDecorator {
	/**
	 * @see	wcf\data\DatabaseObjectDecorator::$baseClass
	 */
	protected static $baseClass = 'wcf\data\modification\log\ModificationLog';
	
	/**
	 * post object
	 * @var	wbb\data\post\Post
	 */
	public $post = null;
	
	/**
	 * user profile object
	 * @var	wcf\data\user\UserProfile
	 */
	protected $userProfile = null;
	
	/**
	 * Returns readable representation of current log entry.
	 */
	public function __toString() {
		return WCF::getLanguage()->getDynamicVariable('wbb.thread.log.post.'.$this->action, array(
			'additionalData' => $this->additionalData,
			'post' => $this->post
		));
	}
	
	/**
	 * Sets post object.
	 * 
	 * @param	wbb\data\post\Post	$post
	 */
	public function setPost(Post $post) {
		if ($post->postID == $this->objectID) {
			$this->post = $post;
		}
	}
	
	/**
	 * Returns the user profile object.
	 * 
	 * @return	wcf\data\user\UserProfile
	 */
	public function getUserProfile() {
		if ($this->userProfile === null) {
			$this->userProfile = new UserProfile(new User(null, $this->getDecoratedObject()->data));
		}
		
		return $this->userProfile;
	}
}
