<?php
namespace wbb\data\post;
use wbb\data\thread\Thread;
use wbb\data\thread\ThreadEditor;
use wcf\data\like\object\AbstractLikeObject;
use wcf\system\request\LinkHandler;

/**
 * Likeable object implementation for posts.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.post
 * @category	Burning Board
 */
class LikeablePost extends AbstractLikeObject {
	/**
	 * @see	wcf\data\DatabaseObjectDecorator::$baseClass
	 */
	protected static $baseClass = 'wbb\data\post\Post';
	
	/**
	 * @see	wcf\data\like\object\ILikeObject::getTitle()
	 */
	public function getTitle() {
		return $this->getDecoratedObject()->getTitle();
	}
	
	/**
	 * @see	wcf\data\like\object\ILikeObject::getURL()
	 */
	public function getURL() {
		return $this->getDecoratedObject()->getLink();
	}
	
	/**
	 * @see	wcf\data\like\object\ILikeObject::getUserID()
	 */
	public function getUserID() {
		return $this->userID;
	}
	
	/**
	 * @see	wcf\data\like\object\ILikeObject::getObjectID()
	 */
	public function getObjectID() {
		return $this->postID;
	}
	
	/**
	 * @see	wcf\data\like\object\ILikeObject::updateLikeCounter()
	 */
	public function updateLikeCounter($cumulativeLikes) {
		// update cumulative likes
		$postEditor = new PostEditor($this->getDecoratedObject());
		$postEditor->update(array(
			'cumulativeLikes' => $cumulativeLikes
		));
		
		// check if this is the first post
		$thread = new Thread($this->threadID);
		if ($thread->firstPostID == $this->postID) {
			$threadEditor = new ThreadEditor($thread);
			$threadEditor->update(array(
				'cumulativeLikes' => $cumulativeLikes
			));
		}
	}
}
