<?php
namespace wbb\data\post;
use wbb\data\modification\log\ViewablePostModificationLog;
use wcf\data\user\User;
use wcf\data\user\UserProfile;
use wcf\data\DatabaseObjectDecorator;
use wcf\system\WCF;

/**
 * Represents a viewable post.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.post
 * @category	Burning Board
 */
class ViewablePost extends DatabaseObjectDecorator {
	/**
	 * @see	wcf\data\DatabaseObjectDecorator::$baseClass
	 */
	protected static $baseClass = 'wbb\data\post\Post';
	
	/**
	 * modification log entry
	 * @var	wbb\data\modification\log\ViewablePostModificationLog
	 */
	protected $logEntry = null;
	
	/**
	 * user profile object
	 * @var wcf\data\user\UserProfile
	 */
	protected $userProfile = null;
	
	/**
	 * Returns the profile object of the user who created the post.
	 * 
	 * @return	wcf\data\user\UserProfile
	 */
	public function getUserProfile() {
		if ($this->userProfile === null) {
			$this->userProfile = new UserProfile(new User(null, $this->getDecoratedObject()->data));
		}
		
		return $this->userProfile;
	}
	
	/**
	 * Sets modification log entry.
	 * 
	 * @param	wbb\data\modification\log\ViewablePostModificationLog		$logEntry
	 */
	public function setLogEntry(ViewablePostModificationLog $logEntry) {
		if ($logEntry->objectID == $this->postID) {
			$this->logEntry = $logEntry;
		}
	}
	
	/**
	 * Returns modification log entry.
	 * 
	 * @return	wbb\data\modification\log\ViewablePostModificationLog
	 */
	public function getLogEntry() {
		return $this->logEntry;
	}
	
	/**
	 * Returns delete note.
	 * 
	 * @return	string
	 */
	public function getDeleteNote() {
		if ($this->logEntry === null) {
			return WCF::getLanguage()->get('wbb.post.deleted.noData');
		}
		
		return WCF::getLanguage()->getDynamicVariable('wbb.post.deleted', array('post' => $this));
	}
}
