<?php
namespace wbb\data\thread;
use wbb\data\board\Board;
use wbb\data\board\BoardCache;
use wcf\system\language\LanguageFactory;
use wcf\system\WCF;

/**
 * Represents a list of accessible threads.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.thread
 * @category	Burning Board
 */
class AccessibleThreadList extends ViewableThreadList {
	/**
	 * Creates a new AccessibleThreadList object.
	 */
	public function __construct() {
		parent::__construct();
		
		// get board ids
		$boardIDs = Board::getAccessibleBoardIDs();
		// remove ignored boards
		if (WCF::getUser()->userID) {
			foreach ($boardIDs as $key => $boardID) {
				if (BoardCache::getInstance()->isIgnored($boardID)) {
					unset($boardIDs[$key]);
				}
			}
		}
		if (!empty($boardIDs)) {
			$this->getConditionBuilder()->add("thread.boardID IN (?)", array($boardIDs));
		}
		else {
			$this->getConditionBuilder()->add("1=0");
		}
		
		// add default conditions
		$this->getConditionBuilder()->add("thread.isDeleted = 0 AND thread.isDisabled = 0 AND thread.movedThreadID IS NULL");
		
		// apply language filter
		if (LanguageFactory::getInstance()->multilingualismEnabled() && count(WCF::getUser()->getLanguageIDs())) {
			$this->getConditionBuilder()->add('(thread.languageID IN (?) OR thread.languageID IS NULL)', array(WCF::getUser()->getLanguageIDs()));
		}
	}
}
