<?php
namespace wbb\data\thread;
use wbb\data\board\Board;
use wbb\data\modification\log\BoardModificationLogList;
use wcf\system\clipboard\ClipboardHandler;

/**
 * Represents a list of deleted threads.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.thread
 * @category	Burning Board
 */
class DeletedThreadList extends ViewableThreadList {
	/**
	 * Creates a new DeletedThreadList object.
	 */
	public function __construct() {
		parent::__construct();
		
		$boardIDs = Board::getAccessibleModeratorBoardIDs(array('canReadDeletedThread'));
		if (!empty($boardIDs)) $this->getConditionBuilder()->add('thread.boardID IN (?)', array($boardIDs));
		else $this->getConditionBuilder()->add('1 = 0');
		$this->getConditionBuilder()->add('thread.isDeleted = ?', array(1));
	}
	
	/**
	 * @see	wcf\data\DatabaseObjectList::readObjects()
	 */
	public function readObjects() {
		parent::readObjects();
		
		// load deletion data
		if (count($this->getObjectIDs())) {
			$this->logList = new BoardModificationLogList();
			$this->logList->setThreadData($this->getObjectIDs(), 'trash');
			$this->logList->readObjects();
				
			foreach ($this->logList as $logEntry) {
				foreach ($this->objects as $thread) {
					if ($thread->threadID == $logEntry->objectID) {
						$thread->setLogEntry($logEntry);
					}
				}
			}
		}
	}
	
	/**
	 * Returns the number of marked items.
	 * 
	 * @return	integer
	 */
	public function getMarkedItems() {
		return ClipboardHandler::getInstance()->hasMarkedItems(ClipboardHandler::getInstance()->getObjectTypeID('com.woltlab.wbb.thread'));
	}
}
