<?php
namespace wbb\data\thread;
use wbb\data\board\BoardCache;
use wcf\system\language\LanguageFactory;
use wcf\system\WCF;

/**
 * Represents a list of threads.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.thread
 * @category	Burning Board
 */
class FeedThreadList extends ViewableThreadList {
	/**
	 * @see	wcf\data\DatabaseObjectList::$decoratorClassName
	 */
	public $decoratorClassName = 'wbb\data\thread\FeedThread';
	
	/**
	 * Creates a new FeedThreadList object.
	 * 
	 * @param	array<integer>		$boardIDs
	 */
	public function __construct(array $boardIDs) {
		parent::__construct();
		
		$this->getConditionBuilder()->add('thread.boardID IN (?)', array($boardIDs));
		
		if (count($boardIDs) == 1) {
			$board = BoardCache::getInstance()->getBoard(reset($boardIDs));
			if (!$board->getModeratorPermission('canReadDeletedThread')) $this->getConditionBuilder()->add('thread.isDeleted = 0');
			if (!$board->getModeratorPermission('canEnableThread')) $this->getConditionBuilder()->add('thread.isDisabled = 0');
		}
		else {
			if (!WCF::getSession()->getPermission('mod.board.isSuperMod') || WCF::getSession()->getPermission('mod.board.canReadDeletedThread')) $this->getConditionBuilder()->add('thread.isDeleted = 0');
			if (!WCF::getSession()->getPermission('mod.board.isSuperMod') || WCF::getSession()->getPermission('mod.board.canEnableThread')) $this->getConditionBuilder()->add('thread.isDisabled = 0');
		}
		// apply language filter
		if (LanguageFactory::getInstance()->multilingualismEnabled() && count(WCF::getUser()->getLanguageIDs())) {
			$this->getConditionBuilder()->add('(thread.languageID IN (?) OR thread.languageID IS NULL)', array(WCF::getUser()->getLanguageIDs()));
		}
		
		$this->getConditionBuilder()->add('thread.movedThreadID IS NULL');
	}
}
