<?php
namespace wbb\data\thread;
use wbb\system\cache\builder\MostActiveThreadsCacheBuilder;
use wbb\data\board\Board;
use wbb\data\board\BoardCache;
use wcf\system\database\util\PreparedStatementConditionBuilder;
use wcf\system\language\LanguageFactory;
use wcf\system\WCF;

/**
 * Represents a list of the most active threads
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.thread
 * @category	Burning Board
 */
class MostActiveThreadList extends ViewableThreadList {
	/**
	 * @see	wcf\data\DatabaseObjectList::$sqlLimit
	 */
	public $sqlLimit = WBB_MOST_ACTIVE_THREADS_ITEMS;
	
	/**
	 * @see	wcf\data\DatabaseObjectList::$sqlOrderBy
	 */
	public $sqlOrderBy = 'thread.replies DESC, thread.lastPostTime DESC';
	
	/**
	 * Creates a new MostActiveThreadList object.
	 * 
	 * @param	integer		$boardID
	 */
	public function __construct($boardID = 0) {
		parent::__construct();
		$this->objectIDs = array();
		
		// get cache
		$cachedThreadIDs = MostActiveThreadsCacheBuilder::getInstance()->getData($boardID ? array('boardID' => $boardID) : array());
		if (!count($cachedThreadIDs)) return;
		
		// add conditions
		$this->getConditionBuilder()->add('thread.threadID IN (?)', array($cachedThreadIDs));
		
		// get boards ids
		if (!$boardID) {
			$boardIDs = Board::getAccessibleBoardIDs(array('canViewBoard', 'canEnterBoard'));
			foreach ($boardIDs as $key => $accessibleBoardID) {
				$board = BoardCache::getInstance()->getBoard($accessibleBoardID);
				if ($board->isIgnored() || !$board->searchable) {
					unset($boardIDs[$key]);
				}
			}
			if (!count($boardIDs)) return;
			$this->getConditionBuilder()->add('thread.boardID IN (?)', array($boardIDs));
		}
		
		$this->getConditionBuilder()->add('thread.isDeleted = 0 AND thread.isDisabled = 0 AND thread.movedThreadID IS NULL');
		// apply language filter
		if (LanguageFactory::getInstance()->multilingualismEnabled() && count(WCF::getUser()->getLanguageIDs())) {
			$this->getConditionBuilder()->add('(thread.languageID IN (?) OR thread.languageID IS NULL)', array(WCF::getUser()->getLanguageIDs()));
		}
		
		// filter cache threads
		$this->readObjectIDs();
		
		// cached threads didnt contain the latest X threads for the active user
		// fallback to non-cached function
		if (count($this->objectIDs) < WBB_MOST_ACTIVE_THREADS_ITEMS && count($cachedThreadIDs) >= WBB_MOST_ACTIVE_THREADS_ITEMS) {
			$this->objectIDs = array();
			$this->conditionBuilder = new PreparedStatementConditionBuilder();
			if ($boardID) {			
				$this->getConditionBuilder()->add('thread.boardID = ?', array($boardID));
			}
			else {
				$this->getConditionBuilder()->add('thread.boardID IN (?)', array($boardIDs));
			}
			$this->getConditionBuilder()->add('thread.time > ?', array(TIME_NOW - (WBB_MOST_ACTIVE_THREADS_PERIOD * 86400)));
			$this->getConditionBuilder()->add('thread.isDeleted = 0 AND thread.isDisabled = 0 AND thread.movedThreadID IS NULL');
			// apply language filter
			if (LanguageFactory::getInstance()->multilingualismEnabled() && count(WCF::getUser()->getLanguageIDs())) {
				$this->getConditionBuilder()->add('(thread.languageID IN (?) OR thread.languageID IS NULL)', array(WCF::getUser()->getLanguageIDs()));
			}
			
			$this->readObjectIDs();
		}
	}
}
