<?php
namespace wbb\data\thread;

/**
 * Represents a list of similar threads.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.thread
 * @category	Burning Board
 */
class SimilarThreadList extends ViewableThreadList {
	/**
	 * @see	wcf\data\DatabaseObjectList::$sqlLimit
	 */
	public $sqlLimit = WBB_THREAD_SIMILAR_THREADS_COUNT;
	
	/**
	 * @see	wcf\data\DatabaseObjectList::$sqlOrderBy
	 */
	public $sqlOrderBy = 'thread.lastPostTime DESC';
	
	/**
	 * @see	wcf\data\DatabaseObjectList::$useQualifiedShorthand
	 */
	public $useQualifiedShorthand = false;
	
	/**
	 * Creates a new SimilarThreadList object.
	 */
	public function __construct() {
		ThreadList::__construct();
		
		$this->sqlJoins = $this->sqlConditionJoins = "LEFT JOIN wbb".WCF_N."_thread thread ON (thread.threadID = thread_similar.similarThreadID)";
		
		// get avatars
		if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
		$this->sqlSelects .= "user_avatar.*, user_table.email, user_table.disableAvatar, user_table.enableGravatar";
		$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_user user_table ON (user_table.userID = thread.userID)";
		$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_user_avatar user_avatar ON (user_avatar.avatarID = user_table.avatarID)";
		
		$this->sqlSelects .= ', thread.*';
	}
	
	/**
	 * @see wcf\data\DatabaseObjectList::readObjectIDs()
	 */
	public function readObjectIDs() {}
	
	/**
	 * @see wcf\data\DatabaseObjectList::getDatabaseTableName()
	 */
	public function getDatabaseTableName() {
		return 'wbb'.WCF_N.'_thread_similar';
	}
	
	/**
	 * @see wcf\data\DatabaseObjectList::getDatabaseTableAlias()
	 */
	public function getDatabaseTableAlias() {
		return 'thread_similar';
	}
}
