<?php
namespace wbb\data\thread;
use wbb\system\label\object\ThreadLabelObjectHandler;
use wcf\data\moderation\queue\ModerationQueue;
use wcf\data\object\type\ObjectTypeCache;
use wcf\system\like\LikeHandler;
use wcf\system\visitTracker\VisitTracker;
use wcf\system\WCF;

/**
 * Represents a list of threads.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	data.thread
 * @category	Burning Board
 */
class ViewableThreadList extends ThreadList {
	/**
	 * @see	wcf\data\DatabaseObjectList::$sqlOrderBy
	 */
	public $sqlOrderBy = 'thread.lastPostTime DESC';
	
	/**
	 * @see	wcf\data\DatabaseObjectList::$decoratorClassName
	 */
	public $decoratorClassName = 'wbb\data\thread\ViewableThread';
	
	/**
	 * Creates a new ViewableThreadList object.
	 */
	public function __construct() {
		parent::__construct();
		
		if (WCF::getUser()->userID != 0) {
			// own posts
			if (WBB_BOARD_THREADS_ENABLE_OWN_POSTS) {
				if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
				$this->sqlSelects = "DISTINCT post.userID AS ownPosts";
				$this->sqlJoins = " LEFT JOIN wbb".WCF_N."_post post ON (post.threadID = thread.threadID AND post.userID = ".WCF::getUser()->userID.")";
			}
			
			// last visit time
			if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
			$this->sqlSelects .= 'tracked_visit.visitTime';
			$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_tracked_visit tracked_visit ON (tracked_visit.objectTypeID = ".VisitTracker::getInstance()->getObjectTypeID('com.woltlab.wbb.thread')." AND tracked_visit.objectID = thread.threadID AND tracked_visit.userID = ".WCF::getUser()->userID.")";
			
			if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
			$this->sqlSelects .= 'tracked_board_visit.visitTime AS boardVisitTime';
			$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_tracked_visit tracked_board_visit ON (tracked_board_visit.objectTypeID = ".VisitTracker::getInstance()->getObjectTypeID('com.woltlab.wbb.board')." AND tracked_board_visit.objectID = thread.boardID AND tracked_board_visit.userID = ".WCF::getUser()->userID.")";
			
			// subscriptions
			if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
			$this->sqlSelects .= 'user_object_watch.watchID, user_object_watch.notification';
			$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_user_object_watch user_object_watch ON (user_object_watch.objectTypeID = ".ObjectTypeCache::getInstance()->getObjectTypeByName('com.woltlab.wcf.user.objectWatch', 'com.woltlab.wbb.thread')->objectTypeID." AND user_object_watch.userID = ".WCF::getUser()->userID." AND user_object_watch.objectID = thread.threadID)";
		}
		
		// get avatars
		if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
		$this->sqlSelects .= "user_avatar.*, user_table.email, user_table.disableAvatar, user_table.enableGravatar";
		$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_user user_table ON (user_table.userID = thread.userID)";
		$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_user_avatar user_avatar ON (user_avatar.avatarID = user_table.avatarID)";
		
		if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
		$this->sqlSelects .= "lastposter_avatar.avatarID AS lastPosterAvatarID, lastposter_avatar.avatarName AS lastPosterAvatarName, lastposter_avatar.avatarExtension AS lastPosterAvatarExtension, lastposter_avatar.width AS lastPosterAvatarWidth, lastposter_avatar.height AS lastPosterAvatarHeight, lastposter_avatar.fileHash AS lastPosterAvatarFileHash,";
		$this->sqlSelects .= "lastposter.email AS lastPosterEmail, lastposter.disableAvatar AS lastPosterDisableAvatar, lastposter.enableGravatar AS lastPosterEnableGravatar";
		$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_user lastposter ON (lastposter.userID = thread.lastPosterID)";
		$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_user_avatar lastposter_avatar ON (lastposter_avatar.avatarID = lastposter.avatarID)";
		
		// get like status
		if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
		$this->sqlSelects .= "like_object.likes, like_object.dislikes";
		$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_like_object like_object ON (like_object.objectTypeID = ".LikeHandler::getInstance()->getObjectType('com.woltlab.wbb.likeablePost')->objectTypeID." AND like_object.objectID = thread.firstPostID)";
		
		// get report status
		if (WCF::getSession()->getPermission('mod.board.isSuperMod')) {
			if (!empty($this->sqlSelects)) $this->sqlSelects .= ',';
			$this->sqlSelects .= "moderation_queue.queueID AS reportQueueID";
			$this->sqlJoins .= " LEFT JOIN wcf".WCF_N."_moderation_queue moderation_queue ON (moderation_queue.objectTypeID = ".ObjectTypeCache::getInstance()->getObjectTypeIDByName('com.woltlab.wcf.moderation.report', 'com.woltlab.wbb.post')." AND moderation_queue.objectID = thread.firstPostID AND moderation_queue.status <> ".ModerationQueue::STATUS_DONE.")";
		}
	}
	
	/**
	 * @see	wcf\data\DatabaseObjectList::readObjects()
	 */
	public function readObjects() {
		if ($this->objectIDs === null) $this->readObjectIDs();
		parent::readObjects();
		
		// get assigned labels
		$threadIDs = array();
		foreach ($this->objects as $thread) {
			if ($thread->hasLabels) {
				$threadIDs[] = $thread->threadID;
			}
		}
		
		if (!empty($threadIDs)) {
			$assignedLabels = ThreadLabelObjectHandler::getInstance()->getAssignedLabels($threadIDs);
			foreach ($assignedLabels as $threadID => $labels) {
				foreach ($labels as $label) {
					$this->objects[$threadID]->addLabel($label);
				}
			}
		}
	}
}
