<?php
namespace wbb\page;
use wbb\data\board\Board;
use wbb\data\board\BoardCache;
use wbb\data\thread\FeedThreadList;
use wcf\page\AbstractFeedPage;
use wcf\system\exception\IllegalLinkException;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\WCF;

/**
 * Shows threads for the specified boards in feed.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	page
 * @category	Burning Board
 */
class BoardFeedPage extends AbstractFeedPage {
	/**
	 * @see	wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (empty($this->objectIDs)) {
			// get all board ids
			$this->objectIDs = Board::getAccessibleBoardIDs(array('canViewBoard', 'canEnterBoard', 'canReadThread'));
			if (empty($this->objectIDs)) {
				throw new IllegalLinkException();
			}
		}
		else {
			// validate ids
			foreach ($this->objectIDs as $objectID) {
				$board = BoardCache::getInstance()->getBoard($objectID);
					
				// wrong ID
				if ($board === null) throw new IllegalLinkException();
					
				// one may not enter
				if (!$board->canEnter()) throw new PermissionDeniedException();
					
				// category or link
				if (!$board->isBoard()) throw new IllegalLinkException();
					
				// threads are not accessible
				if (!$board->getPermission('canReadThread')) throw new PermissionDeniedException();
			}
		}
	}
	
	/**
	 * @see	wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		// read the threads
		$this->items = new FeedThreadList($this->objectIDs);
		$this->items->sqlLimit = 20;
		$this->items->readObjects();
		
		// set title
		if (count($this->objectIDs) === 1) {
			$this->title = BoardCache::getInstance()->getBoard(reset($this->objectIDs))->getTitle();
		}
		else {
			$this->title = WCF::getLanguage()->get('wbb.header.menu.board');
		}
	}
}
