<?php
namespace wbb\page;
use wbb\data\board\DetailedBoardNodeList;
use wcf\data\user\online\UsersOnlineList;
use wcf\data\option\OptionAction;
use wcf\page\AbstractPage;
use wbb\system\cache\builder\StatsCacheBuilder;
use wcf\system\cache\builder\UserStatsCacheBuilder;
use wcf\system\dashboard\DashboardHandler;
use wcf\system\menu\page\PageMenu;
use wcf\system\request\LinkHandler;
use wcf\system\user\collapsible\content\UserCollapsibleContentHandler;
use wcf\system\MetaTagHandler;
use wcf\system\WCF;

/**
 * Shows the start page of the forum.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	page
 * @category	Burning Board
 */
class BoardListPage extends AbstractPage {
	/**
	 * @see	wcf\page\AbstractPage::$activeMenuItem
	 */
	public $activeMenuItem = 'wbb.header.menu.board';
	
	/**
	 * board node list
	 * @var	wbb\data\board\BoardNodeList
	 */
	public $boardNodeList = null;
	
	/**
	 * users online list
	 * @var	wcf\data\user\online\UsersOnlineList
	 */
	public $usersOnlineList = null;
	
	/**
	 * simple forum statistics
	 * @var	array
	 */
	public $stats = array();
	
	/**
	 * @see wcf\page\AbstractPage::$enableTracking
	 */
	public $enableTracking = true;
	
	/**
	 * @see	wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		// get node tree
		$this->boardNodeList = new DetailedBoardNodeList();
		$this->boardNodeList->readNodeTree();
		
		// stats
		if (WBB_INDEX_ENABLE_STATS) {
			$this->stats = array_merge(
				StatsCacheBuilder::getInstance()->getData(),
				UserStatsCacheBuilder::getInstance()->getData()
			);
		}
		
		// users online
		if (MODULE_USERS_ONLINE && WBB_INDEX_ENABLE_ONLINE_LIST) {
			$this->usersOnlineList = new UsersOnlineList();
			$this->usersOnlineList->readStats();
			$this->usersOnlineList->getConditionBuilder()->add('session.userID IS NOT NULL');
			$this->usersOnlineList->readObjects();
			
			// check users online record
			$usersOnlineTotal = (WBB_USERS_ONLINE_RECORD_NO_GUESTS ? $this->usersOnlineList->stats['members'] : $this->usersOnlineList->stats['total']);
			if ($usersOnlineTotal > WBB_USERS_ONLINE_RECORD) {
				// save new record
				$optionAction = new OptionAction(array(), 'import', array('data' => array(
					'wbb_users_online_record' => $usersOnlineTotal,
					'wbb_users_online_record_time' => TIME_NOW
				)));
				$optionAction->executeAction();
			}
		}
		
		// remove default breadcrumb entry and set current page as 'website'
		if (PageMenu::getInstance()->getLandingPage()->menuItem == 'wbb.header.menu.board') {
			WCF::getBreadcrumbs()->remove(0);
			
			MetaTagHandler::getInstance()->addTag('og:url', 'og:url', LinkHandler::getInstance()->getLink('BoardList', array('application' => 'wbb')), true);
			MetaTagHandler::getInstance()->addTag('og:type', 'og:type', 'website', true);
			MetaTagHandler::getInstance()->addTag('og:title', 'og:title', WCF::getLanguage()->get(PAGE_TITLE), true);
			MetaTagHandler::getInstance()->addTag('og:description', 'og:description', WCF::getLanguage()->get(PAGE_DESCRIPTION), true);
		}
	}
	
	/**
	 * @see	wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		DashboardHandler::getInstance()->loadBoxes('com.woltlab.wbb.BoardListPage', $this);
		
		WCF::getTPL()->assign(array(
			'boardNodeList' => $this->boardNodeList->getNodeList(),
			'sidebarCollapsed' => UserCollapsibleContentHandler::getInstance()->isCollapsed('com.woltlab.wcf.collapsibleSidebar', 'com.woltlab.wbb.BoardListPage'),
			'sidebarName' => 'com.woltlab.wbb.BoardListPage',
			'stats' => $this->stats,
			'usersOnlineList' => $this->usersOnlineList,
			'allowSpidersToIndexThisPage' => true
		));
	}
}
