<?php
namespace wbb\page;
use wbb\data\board\Board;
use wbb\data\thread\Thread;
use wbb\system\WBBCore;
use wcf\page\SortablePage;
use wcf\system\exception\IllegalLinkException;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\WCF;

/**
 * Shows the thread log page.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	page
 * @category	Burning Board
 */
class ThreadLogPage extends SortablePage {
	/**
	 * @see	wcf\page\AbstractPage::$activeMenuItem
	 */
	public $activeMenuItem = 'wbb.header.menu.board';
	
	/**
	 * board object
	 * @var	wbb\data\board\Board
	 */
	public $board = null;
	
	/**
	 * @see	wcf\page\SortablePage::$defaultSortField
	 */
	public $defaultSortField = 'time';
	
	/**
	 * @see	wcf\page\SortablePage::$defaultSortOrder
	 */
	public $defaultSortOrder = 'DESC';
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$objectListClassName
	 */
	public $objectListClassName = 'wbb\data\modification\log\ThreadLogModificationLogList';
	
	/**
	 * thread id
	 * @var	integer
	 */
	public $threadID = 0;
	
	/**
	 * thread object
	 * @var	wbb\data\thread\Thread
	 */
	public $thread = null;
	
	/**
	 * @see	wcf\page\SortablePage::$validSortFields
	 */
	public $validSortFields = array('logID', 'time', 'username');
	
	/**
	 * @see	wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['id'])) $this->threadID = intval($_REQUEST['id']);
		$this->thread = new Thread($this->threadID);
		if ($this->thread === null || $this->thread->movedThreadID) {
			throw new IllegalLinkException();
		}
		
		$this->board = new Board($this->thread->boardID);
		if (!$this->board->canEditThreads()) {
			throw new PermissionDeniedException();
		}
	}
	
	/**
	 * @see	wcf\page\MultipleLinkPage::initObjectList()
	 */
	protected function initObjectList() {
		parent::initObjectList();
		
		$this->objectList->setThread($this->thread);
	}
	
	/**
	 * @see	wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		// add breadcrumbs
		WBBCore::getInstance()->setBreadcrumbs($this->board->getParentBoards(), $this->board, $this->thread);
	}
	
	/**
	 * @see	wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'board' => $this->board,
			'thread' => $this->thread
		));
	}
}
