<?php
namespace wbb\system;
use wbb\data\board\Board;
use wbb\data\thread\Thread;
use wcf\system\menu\page\PageMenu;
use wcf\system\application\AbstractApplication;
use wcf\system\breadcrumb\Breadcrumb;
use wcf\system\request\LinkHandler;
use wcf\system\WCF;

/**
 * This class extends the main WCF class by forum specific functions.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system
 * @category	Burning Board
 */
class WBBCore extends AbstractApplication {
	/**
	 * @see	wcf\system\application\AbstractApplication::$abbreviation
	 */
	protected $abbreviation = 'wbb';
	
	/**
	 * Sets the WBB breadcrumbs.
	 * 
	 * @param	array<wbb\data\board\Board>		$parentBoards
	 * @param	wbb\data\board\Board			$board
	 * @param	wbb\data\thread\Thread			$thread
	 */
	public function setBreadcrumbs(array $parentBoards = array(), Board $board = null, Thread $thread = null) {
		// add main entry
		if (PageMenu::getInstance()->getLandingPage()->menuItem != 'wbb.header.menu.board') {
			WCF::getBreadcrumbs()->add(new Breadcrumb(WCF::getLanguage()->get('wbb.header.menu.board'), LinkHandler::getInstance()->getLink('BoardList', array(
				'application' => 'wbb'
			))));
		}
		
		// add parent boards
		foreach ($parentBoards as $parentBoard) {
			WCF::getBreadcrumbs()->add($parentBoard->getBreadcrumb());
		}
		
		// add board
		if ($board !== null) {
			WCF::getBreadcrumbs()->add($board->getBreadcrumb());
		}
		
		// add thread
		if ($thread !== null) {
			WCF::getBreadcrumbs()->add($thread->getBreadcrumb());
		}
	}
}
