<?php
namespace wbb\system\attachment;
use wbb\data\board\BoardCache;
use wbb\data\post\Post;
use wbb\data\post\PostList;
use wcf\system\attachment\AbstractAttachmentObjectType;

/**
 * Attachment object type implementation for posts.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.attachment
 * @category	Burning Board
 */
class PostAttachmentObjectType extends AbstractAttachmentObjectType {
	/**
	 * cached post objects
	 * @var array<wbb\data\post\Post>
	 */
	protected $cachedObjects = array();
	
	/**
	 * @see	wcf\system\attachment\IAttachmentObjectType::canDownload()
	 */
	public function canDownload($objectID) {
		if ($objectID) {
			$post = new Post($objectID);
			if (!$post->canRead()) return false;
			
			$board = BoardCache::getInstance()->getBoard($post->getThread()->boardID);
			return $board->getPermission('canDownloadAttachment');
		}
		
		return false;
	}
	
	/**
	 * @see	wcf\system\attachment\IAttachmentObjectType::canViewPreview()
	 */
	public function canViewPreview($objectID) {
		if ($objectID) {
			$post = new Post($objectID);
			if (!$post->canRead()) return false;
			
			$board = BoardCache::getInstance()->getBoard($post->getThread()->boardID);
			return $board->getPermission('canViewAttachmentPreview');
		}
		
		return false;
	}
	
	/**
	 * @see	wcf\system\attachment\IAttachmentObjectType::canUpload()
	 */
	public function canUpload($objectID, $parentObjectID = 0) {
		$board = null;
		if ($objectID) {
			$post = new Post($objectID);
			if (!$post->getThread()->canEditPost($post)) return false;
			
			$board = BoardCache::getInstance()->getBoard($post->getThread()->boardID);
		}
		else if ($parentObjectID) {
			$board = BoardCache::getInstance()->getBoard($parentObjectID);
		}
		
		if ($board !== null) { 
			return $board->getPermission('canUploadAttachment');
		}
		
		return false;
	}
	
	/**
	 * @see	wcf\system\attachment\IAttachmentObjectType::canDelete()
	 */
	public function canDelete($objectID) {
		if ($objectID) {
			$post = new Post($objectID);
			if ($post->getThread()->canEditPost($post)) return true;
		}
		
		return false;
	}
	
	/**
	 * @see	wcf\system\attachment\IAttachmentObjectType::getObject()
	 */
	public function getObject($objectID) {
		if (isset($this->cachedObjects[$objectID])) return $this->cachedObjects[$objectID];
		
		return null;
	}
	
	/**
	 * @see	wcf\system\attachment\IAttachmentObjectType::cacheObjects()
	 */
	public function cacheObjects(array $objectIDs) {
		$postList = new PostList();
		$postList->setObjectIDs($objectIDs);
		$postList->readObjects();
		$this->cachedObjects = $postList->getObjects();
	}
}
