<?php
namespace wbb\system\board;
use wcf\system\SingletonFactory;
use wcf\system\WCF;

/**
 * Handles individual permissions for boards.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.board
 * @category	Burning Board
 */
class BoardPermissionHandler extends SingletonFactory {
	/**
	 * list of permissions
	 * @var	array
	 */
	protected $boardPermissions = array();
	
	/**
	 * list of mod permissions
	 * @var	array
	 */
	protected $moderatorPermissions = array();
	
	/**
	 * @see	wcf\system\SingletonFactory::init()
	 */
	protected function init() {
		$this->boardPermissions = BoardPermissionCache::getInstance()->getPermissions(WCF::getUser());
		if (WCF::getUser()->userID) {
			$this->moderatorPermissions = BoardPermissionCache::getInstance()->getModeratorPermissions(WCF::getUser());
		}
	}
	
	/**
	 * Returns the board permission with the given name for the board with the
	 * given id.
	 * 
	 * @param	integer		$boardID
	 * @param	string		$permission
	 * @return	boolean
	 */
	public function getPermission($boardID, $permission) {
		if (isset($this->boardPermissions[$boardID][$permission])) return $this->boardPermissions[$boardID][$permission];
		
		return WCF::getSession()->getPermission('user.board.'.$permission);
	}
	
	/**
	 * Returns the board moderator permission with the given name for the board
	 * with the given id.
	 * 
	 * @param	integer		$boardID
	 * @param	string		$permission
	 * @return	boolean
	 */
	public function getModeratorPermission($boardID, $permission) {
		if (isset($this->moderatorPermissions[$boardID][$permission])) return $this->moderatorPermissions[$boardID][$permission];
		
		return WCF::getSession()->getPermission('mod.board.'.$permission);
	}
}
