<?php
namespace wbb\system\cache\builder;
use wbb\data\board\BoardCache;
use wcf\system\cache\builder\AbstractCacheBuilder;
use wcf\system\WCF;

/**
 * Caches latest posts.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.cache.builder
 * @category	Burning Board
 */
class LatestPostsCacheBuilder extends AbstractCacheBuilder {
	/**
	 * @see	wcf\system\cache\builder\AbstractCacheBuilder::$maxLifetime
	 */
	protected $maxLifetime = 180;
	
	/**
	 * @see	wcf\system\cache\builder\AbstractCacheBuilder::rebuild()
	 */
	protected function rebuild(array $parameters) {
		// get boards ids
		$boardIDs = array();
		foreach (BoardCache::getInstance()->getBoards() as $board) {
			if ($board->searchable) $boardIDs[] = $board->boardID;
		}
		
		// get thread ids
		$threadIDs = array();
		if (!empty($boardIDs)) {
			$sql = "SELECT		thread.threadID
				FROM		wbb".WCF_N."_thread thread
				WHERE		thread.boardID IN (".implode(',', $boardIDs).")
						AND thread.isDeleted = 0
						AND thread.isDisabled = 0
						AND thread.movedThreadID IS NULL
				ORDER BY	thread.lastPostTime DESC";
			$statement = WCF::getDB()->prepareStatement($sql, WBB_LATEST_POSTS_ITEMS * 10);
			$statement->execute();
			while ($row = $statement->fetchArray()) {
				$threadIDs[] = $row['threadID'];
			}
		}
		
		return $threadIDs;
	}
}
