<?php
namespace wbb\system\cache\builder;
use wbb\data\thread\ViewableThreadList;
use wcf\system\cache\builder\AbstractCacheBuilder;
use wcf\system\WCF;

/**
 * Caches most active threads.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.cache.builder
 * @category	Burning Board
 */
class MostActiveThreadsCacheBuilder extends AbstractCacheBuilder {
	/**
	 * @see	wcf\system\cache\builder\AbstractCacheBuilder::$maxLifetime
	 */
	protected $maxLifetime = 3600;
	
	/**
	 * @see	wcf\system\cache\builder\AbstractCacheBuilder::rebuild()
	 */
	protected function rebuild(array $parameters) {
		// get thread ids
		$sql = "SELECT		threadID
			FROM		wbb".WCF_N."_thread
			WHERE		".(!empty($parameters['boardID']) ? "boardID = ? AND" : '')."
					time > ?
					AND isDisabled = 0
					AND isDeleted = 0
					AND movedThreadID IS NULL
			ORDER BY	replies DESC, lastPostTime DESC";
		$statement = WCF::getDB()->prepareStatement($sql, !empty($parameters['boardID']) ? WBB_MOST_ACTIVE_THREADS_ITEMS : WBB_MOST_ACTIVE_THREADS_ITEMS * 10);
		if (!empty($parameters['boardID'])) {
			$statement->execute(array(
				$parameters['boardID'],
				(TIME_NOW - (WBB_MOST_ACTIVE_THREADS_PERIOD * 86400))
			));
		}
		else {
			$statement->execute(array(
				(TIME_NOW - (WBB_MOST_ACTIVE_THREADS_PERIOD * 86400))
			));
		}
		$threadIDs = array();
		while ($row = $statement->fetchArray()) {
			$threadIDs[] = $row['threadID'];
		}
		
		return $threadIDs;
	}
}
