<?php
namespace wbb\system\cache\builder;
use wcf\system\cache\builder\AbstractCacheBuilder;
use wcf\system\WCF;

/**
 * Caches the amount posts and threads and the posts per day.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.cache.builder
 * @category	Burning Board
 */
class StatsCacheBuilder extends AbstractCacheBuilder {
	/**
	 * @see	wcf\system\cache\builder\AbstractCacheBuilder::$maxLifetime
	 */
	protected $maxLifetime = 600;
	
	/**
	 * @see	wcf\system\cache\builder\AbstractCacheBuilder::rebuild()
	 */
	protected function rebuild(array $parameters) {
		$data = array();
		
		// amount of posts
		$sql = "SELECT	COUNT(*) AS amount
			FROM	wbb".WCF_N."_post";
		$statement = WCF::getDB()->prepareStatement($sql);
		$statement->execute();
		$data['posts'] = $statement->fetchColumn();
		
		// amount of threads
		$sql = "SELECT	COUNT(*) AS amount
			FROM	wbb".WCF_N."_thread";
		$statement = WCF::getDB()->prepareStatement($sql);
		$statement->execute();
		$data['threads'] = $statement->fetchColumn();
		
		// posts per day
		$days = ceil((TIME_NOW - WBB_INSTALL_DATE) / 86400);
		if ($days <= 0) $days = 1;
		$data['postsPerDay'] = $data['posts'] / $days;
		
		return $data;
	}
}
