<?php
namespace wbb\system\dashboard\box;
use wbb\data\board\BoardTagCloud;
use wbb\data\thread\LatestPostsList;
use wbb\page\BoardPage;
use wcf\data\dashboard\box\DashboardBox;
use wcf\page\IPage;
use wcf\system\dashboard\box\AbstractSidebarDashboardBox;
use wcf\system\language\LanguageFactory;
use wcf\system\tagging\TypedTagCloud;
use wcf\system\WCF;

/**
 * Dashboard sidebar box for tag cloud within boards.
 *
 * @author 	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.dashboard.box
 * @category 	Burning Board
 */
class BoardTagCloudDashboardBox extends AbstractSidebarDashboardBox {
	/**
	 * board tag cloud
	 * @var	wbb\data\board\BoardTagCloud
	 */
	public $boardTagCloud = null;
	
	/**
	 * tag cloud
	 * @var wcf\system\tagging\TypedTagCloud
	 */
	public $tagCloud = null;
	
	/**
	 * @see	wcf\system\dashboard\box\IDashboardBox::init()
	 */
	public function init(DashboardBox $box, IPage $page) {
		parent::init($box, $page);
		
		if (MODULE_TAGGING && WBB_THREAD_ENABLE_TAGS) {
			$languageIDs = array();
			if (LanguageFactory::getInstance()->multilingualismEnabled()) {
				$languageIDs = WCF::getUser()->getLanguageIDs();
			}
			
			if ($page instanceof BoardPage) {
				$this->boardTagCloud = new BoardTagCloud($this->page->boardID, $languageIDs);
			}
			else {
				$this->tagCloud = new TypedTagCloud('com.woltlab.wbb.thread', $languageIDs);
			}
		}
		
		$this->fetched();
	}
	
	/**
	 * @see	wcf\system\dashboard\box\AbstractContentDashboardBox::render()
	 */
	protected function render() {
		if ($this->boardTagCloud === null && $this->tagCloud === null) {
			return '';
		}
		
		if ($this->boardTagCloud === null) {
			WCF::getTPL()->assign(array(
				'tags' => $this->tagCloud->getTags()
			));
			
			return WCF::getTPL()->fetch('tagCloudBox');
		}
		else {
			WCF::getTPL()->assign(array(
				'board' => $this->page->board,
				'tagLinkParameters' => $this->page->tagLinkParameters,
				'tags' => $this->boardTagCloud->getTags()
			));
			
			return WCF::getTPL()->fetch('boardTagCloudBox', 'wbb');
		}
	}
}
