<?php
namespace wbb\system\dashboard\box;
use wbb\data\board\BoardCache;
use wbb\data\thread\NewsList;
use wcf\data\dashboard\box\DashboardBox;
use wcf\page\IPage;
use wcf\system\dashboard\box\AbstractContentDashboardBox;
use wcf\system\WCF;

/**
 * Dashboard sidebar box for news.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.dashboard.box
 * @category	Burning Board
 */
class ThreadsAsNewsContentDashboardBox extends AbstractContentDashboardBox {
	/**
	 * news list
	 * @var	wbb\data\thread\NewsList
	 */
	public $newsList = null;
	
	/**
	 * @see	wcf\system\dashboard\box\IDashboardBox::init()
	 */
	public function init(DashboardBox $box, IPage $page) {
		parent::init($box, $page);
		
		// check config
		if (!WBB_NEWS_BOARD_ID) return;
		
		// init news list
		$this->newsList = new NewsList();
		$this->newsList->getConditionBuilder()->add('thread.boardID IN (?)', array(explode("\n", WBB_NEWS_BOARD_ID)));
		$this->newsList->readObjects();
		if ($this->newsList->getAttachmentList() !== null) {
			// get permissions
			$canDownload = true;
			$canViewPreview = true;
			foreach (explode("\n", WBB_NEWS_BOARD_ID) as $boardID) {
				$board = BoardCache::getInstance()->getBoard($boardID);
				if ($board !== null) {
					if (!$board->getPermission('canDownloadAttachment')) $canDownload = false;
					if (!$board->getPermission('canViewAttachmentPreview')) $canViewPreview = false;
				}
			}
			
			// set permissions
			$this->newsList->getAttachmentList()->setPermissions(array(
				'canDownload' => $canDownload,
				'canViewPreview' => $canViewPreview
			));
		}
		
		$this->fetched();
	}
	
	/**
	 * @see	wcf\system\dashboard\box\AbstractContentDashboardBox::render()
	 */
	protected function render() {
		if ($this->newsList === null) return;
		
		if (count($this->newsList)) {
			WCF::getTPL()->assign(array(
				'newsList' => $this->newsList
			));
			
			return WCF::getTPL()->fetch('dashboardBoxThreadsAsNews', 'wbb');
		}
	}
}
