<?php
namespace wbb\system\dashboard\box;
use wbb\system\cache\builder\TopPosterCacheBuilder;
use wcf\data\dashboard\box\DashboardBox;
use wcf\data\user\UserProfileList;
use wcf\page\IPage;
use wcf\system\dashboard\box\AbstractSidebarDashboardBox;
use wcf\system\WCF;

/**
 * Shows a list of the top poster.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.dashboard.box
 * @category	Burning Board
 */
class TopPosterDashboardBox extends AbstractSidebarDashboardBox {
	/**
	 * user profile list object
	 * @var	wcf\data\user\UserProfileList
	 */
	public $userProfileList = null;
	
	/**
	 * @see	wcf\system\dashboard\box\IDashboardBox::init()
	 */
	public function init(DashboardBox $box, IPage $page) {
		parent::init($box, $page);
		
		// get ids
		$topPosterIDs = TopPosterCacheBuilder::getInstance()->getData();
		if (empty($topPosterIDs)) return '';
		
		// get profile data
		$this->userProfileList = new UserProfileList();
		$this->userProfileList->sqlOrderBy = 'user_table.wbbPosts DESC';
		$this->userProfileList->setObjectIDs($topPosterIDs);
		$this->userProfileList->readObjects();
		
		$this->fetched();
	}
	
	/**
	 * @see	wcf\system\dashboard\box\AbstractContentDashboardBox::render()
	 */
	protected function render() {
		if (count($this->userProfileList)) {
			WCF::getTPL()->assign(array(
				'topPoster' => $this->userProfileList
			));
			
			return WCF::getTPL()->fetch('dashboardBoxTopPoster', 'wbb');
		}
		
		return '';
	}
}
