<?php
namespace wbb\system\event\listener;
use wbb\data\board\BoardCache;
use wcf\system\database\util\PreparedStatementConditionBuilder;
use wcf\system\event\IEventListener;
use wcf\system\WCF;

/**
 * Updates users' post counter.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.event.listener
 * @category	Burning Board
 */
class UserRebuildDataWorkerListener implements IEventListener {
	/**
	 * @see	wcf\system\event\IEventListener::execute()
	 */
	public function execute($eventObj, $className, $eventName) {
		$userIDs = array();
		foreach ($eventObj->getObjectList() as $user) {
			$userIDs[] = $user->userID;
		}
		
		if (!empty($userIDs)) {
			// get boards ids
			$boardIDs = array();
			foreach (BoardCache::getInstance()->getBoards() as $board) {
				if ($board->countUserPosts) $boardIDs[] = $board->boardID;
			}
			
			// update post counter
			if (!empty($boardIDs)) {
				$conditionBuilder = new PreparedStatementConditionBuilder();
				$conditionBuilder->add('user_table.userID IN (?)', array($userIDs));
				$sql = "UPDATE	wcf".WCF_N."_user user_table
					SET	wbbPosts = (
							SELECT	COUNT(*)
							FROM	wbb".WCF_N."_post post,
								wbb".WCF_N."_thread thread	
							WHERE	post.userID = user_table.userID
								AND thread.threadID = post.threadID		
								AND thread.boardID IN (".implode(',', $boardIDs).")
								AND post.isDeleted = 0
								AND post.isDisabled = 0
						)
					".$conditionBuilder;
				$statement = WCF::getDB()->prepareStatement($sql);
				$statement->execute($conditionBuilder->getParameters());
			}
		}
	}
}
