<?php
namespace wbb\system\event\listener;
use wbb\data\board\BoardCache;
use wcf\system\database\util\PreparedStatementConditionBuilder;
use wcf\system\event\IEventListener;
use wcf\system\WCF;

/**
 * Extends the daily system cleanup.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.event.listener
 * @category	Burning Board
 */
class WBBCleanUpListener implements IEventListener {
	/**
	 * @see	\wcf\system\event\IEventListener::execute()
	 */
	public function execute($eventObj, $className, $eventName) {
		// mark threads as done
		if (WBB_MODULE_THREAD_MARKING_AS_DONE && WBB_THREAD_MARKING_AS_DONE_CYCLE) {
			$boardIDs = array();
			foreach (BoardCache::getInstance()->getBoards() as $board) {
				if ($board->enableMarkingAsDone) $boardIDs[] = $board->boardID;
			}
			
			if (!empty($boardIDs)) {
				$conditionBuilder = new PreparedStatementConditionBuilder();
				$conditionBuilder->add('boardID IN (?)', array($boardIDs));
				$conditionBuilder->add('lastPostTime < ?', array((TIME_NOW - WBB_THREAD_MARKING_AS_DONE_CYCLE * 86400)));
				
				$sql = "UPDATE	wbb".WCF_N."_thread
					SET	isDone = 1
					".$conditionBuilder;
				$statement = WCF::getDB()->prepareStatement($sql);
				$statement->execute($conditionBuilder->getParameters());
			}
		}
		
		// delete move notices
		if (WBB_THREAD_DELETE_LINK_CYCLE) {
			$sql = "DELETE FROM	wbb".WCF_N."_thread
				WHERE		movedTime > ?
						AND movedTime < ?";
			$statement = WCF::getDB()->prepareStatement($sql);
			$statement->execute(array(0, (TIME_NOW - WBB_THREAD_DELETE_LINK_CYCLE * 86400)));
		}
	}
}
