<?php
namespace wbb\system\event\listener;
use wbb\data\thread\ThreadList;
use wcf\system\event\IEventListener;
use wcf\system\request\LinkHandler;
use wcf\system\Callback;
use wcf\system\Regex;

/**
 * Parses URLs of threads.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.event.listener
 * @category	Burning Board
 */
class WBBPreParserListener implements IEventListener {
	/**
	 * @see	wcf\system\event\IEventListener::execute()
	 */
	public function execute($eventObj, $className, $eventName) {
		if (!$eventObj->text) return;
		$threadIDs = array();
		
		// build search pattern
		$regex = new Regex('\[url\]('.preg_quote(LinkHandler::getInstance()->getLink('Thread', array(
			'application' => 'wbb'
		))).'(\d+)-.*?)\[/url\]');
		
		// find thread ids
		if ($regex->match($eventObj->text, true)) {
			$matches = $regex->getMatches();
			$threadIDs = array_unique($matches[2]);
		}
		
		if (!empty($threadIDs)) {
			// get threads
			$threadList = new ThreadList();
			$threadList->setObjectIDs($threadIDs);
			$threadList->readObjects();
			
			$threads = array();
			// check permissions
			foreach ($threadList as $thread) {
				if ($thread->canRead()) $threads[$thread->threadID] = $thread;
			}
			
			if (!empty($threads)) {
				$callback = new Callback(function ($matches) use ($threads) {
					if (isset($threads[$matches[2]])) {
						return "[url='".$matches[1]."']".$threads[$matches[2]]->topic."[/url]";
					}
						
					return $matches[0];
				});
				
				$eventObj->text = $regex->replace($eventObj->text, $callback);
			}
		}
	}
}
