<?php
namespace wbb\system\label\object\type;
use wbb\data\board\BoardEditor;
use wbb\data\board\RealtimeBoardNodeList;
use wcf\system\label\object\type\AbstractLabelObjectTypeHandler;
use wcf\system\label\object\type\LabelObjectType;
use wcf\system\label\object\type\LabelObjectTypeContainer;

/**
 * Object type handler for boards.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2012 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.label.object.type
 * @category	Burning Board
 */
class BoardLabelObjectTypeHandler extends AbstractLabelObjectTypeHandler {
	/**
	 * board node list
	 * @var	wbb\data\board\RealtimeBoardNodeList
	 */
	public $boardNodeList = null;
	
	/**
	 * object type id
	 * @var	integer
	 */
	public $objectTypeID = 0;
	
	/**
	 * @see	wcf\system\SingletonFactory::init()
	 */
	protected function init() {
		// get board list
		$this->boardNodeList = new RealtimeBoardNodeList();
		$this->boardNodeList->readNodeTree();
	}
	
	/**
	 * @see	wcf\system\label\object\type\AbstractLabelObjectTypeHandler::setObjectTypeID()
	 */
	public function setObjectTypeID($objectTypeID) {
		parent::setObjectTypeID($objectTypeID);
		
		// build label object type container
		$this->container = new LabelObjectTypeContainer($this->objectTypeID);
		
		foreach ($this->boardNodeList->getNodeList() as $boardNode) {
			// ignore links
			if ($boardNode->getBoard()->isExternalLink()) {
				continue;
			}
				
			$objectType = new LabelObjectType($boardNode->getBoard()->getTitle(), $boardNode->getBoard()->boardID, ($boardNode->getDepth() - 1), $boardNode->getBoard()->isCategory());
			$this->container->add($objectType);
		}
	}
	
	/**
	 * @see	wcf\system\label\object\type\ILabelObjectTypeHandler::save()
	 */
	public function save() {
		BoardEditor::resetCache();
	}
}
