<?php
namespace wbb\system\log\modification;
use wbb\data\post\Post;
use wcf\system\log\modification\ModificationLogHandler;

/**
 * Handles post modification logs.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.log.modification
 * @category	Burning Board
 */
class PostModificationLogHandler extends ModificationLogHandler {
	/**
	 * Adds a log entry for post close.
	 * 
	 * @param	wbb\data\post\Post	$post
	 */
	public function close(Post $post) {
		$this->add($post, 'close');
	}
	
	/**
	 * Adds a log entry for post delete.
	 * 
	 * @param	wbb\data\post\Post	$post
	 */
	public function delete(Post $post) {
		$this->add($post, 'delete', array(
			'time' => $post->time,
			'username' => $post->username
		));
	}
	
	/**
	 * Adds a log entry for post disabling.
	 * 
	 * @param	wbb\data\post\Post	$post
	 */
	public function disable(Post $post) {
		$this->add($post, 'disable');
	}
	
	/**
	 * Adds a log entry for post edit.
	 * 
	 * @param	wbb\data\post\Post	$post
	 * @param	string			$reason
	 */
	public function edit(Post $post, $reason = '') {
		$this->add($post, 'edit', array('reason' => $reason));
	}
	
	/**
	 * Adds a log entry for post enabling.
	 * 
	 * @param	wbb\data\post\Post	$post
	 */
	public function enable(Post $post) {
		$this->add($post, 'enable');
	}
	
	/**
	 * Adds a log entry for post open.
	 * 
	 * @param	wbb\data\post\Post	$post
	 */
	public function open(Post $post) {
		$this->add($post, 'open');
	}
	
	/**
	 * Adds a log entry for post restore.
	 * 
	 * @param	wbb\data\post\Post	$post
	 */
	public function restore(Post $post) {
		$this->add($post, 'restore');
	}
	
	/**
	 * Adds a log entry for post soft-delete (trash).
	 * 
	 * @param	wbb\data\post\Post	$post
	 * @param	string			$reason
	 */
	public function trash(Post $post, $reason = '') {
		$this->add($post, 'trash', array('reason' => $reason));
	}
	
	/**
	 * Adds a post modification log entry.
	 * 
	 * @param	wbb\data\post\Post	$post
	 * @param	string			$action
	 * @param	array			$additionalData
	 */
	public function add(Post $post, $action, array $additionalData = array()) {
		parent::_add('com.woltlab.wbb.post', $post->postID, $action, $additionalData);
	}
}
