<?php
namespace wbb\system\log\modification;
use wbb\data\board\Board;
use wbb\data\thread\Thread;
use wcf\data\label\Label;
use wcf\system\log\modification\ModificationLogHandler;

/**
 * Handles thread modification logs.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.log.modification
 * @category	Burning Board
 */
class ThreadModificationLogHandler extends ModificationLogHandler {
	/**
	 * Adds a log entry for thread close.
	 * 
	 * @param	wbb\data\thread\Thread		$thread
	 */
	public function close(Thread $thread) {
		$this->add($thread, 'close');
	}
	
	/**
	 * Adds a log entry for thread delete.
	 * 
	 * @param	wbb\data\thread\Thread		$thread
	 */
	public function delete(Thread $thread) {
		$this->add($thread, 'delete', array(
			'time' => $thread->time,
			'topic' => $thread->topic
		));
	}
	
	/**
	 * Adds a log entry for thread marking as done.
	 * 
	 * @param	wbb\data\thread\Thread		$thread
	 */
	public function done(Thread $thread) {
		$this->add($thread, 'done');
	}
	
	/**
	 * Adds a log entry for thread enable.
	 * 
	 * @param	wbb\data\thread\Thread		$thread
	 */
	public function enable(Thread $thread) {
		$this->add($thread, 'enable');
	}
	
	/**
	 * Adds a log entry for thread disable.
	 *
	 * @param	wbb\data\thread\Thread		$thread
	 */
	public function disable(Thread $thread) {
		$this->add($thread, 'disable');
	}
	
	/**
	 * Adds a log entry for thread move.
	 * 
	 * @param	wbb\data\thread\Thread		$thread
	 * @param	wbb\data\board\Board		$oldBoard
	 * @param	wbb\data\board\Board		$newBoard
	 */
	public function move(Thread $thread, Board $oldBoard, Board $newBoard) {
		$this->add($thread, 'move', array(
			'oldBoard' => array(
				'boardID' => $oldBoard->boardID,
				'title' => $oldBoard->title
			),
			'newBoard' => array(
				'boardID' => $newBoard->boardID,
				'title' => $newBoard->title
			)
		));
	}
	
	/**
	 * Adds a log entry for thread open.
	 *
	 * @param	wbb\data\thread\Thread		$thread
	 */
	public function open(Thread $thread) {
		$this->add($thread, 'open');
	}
	
	/**
	 * Adds a log entry for thread restore.
	 *
	 * @param	wbb\data\thread\Thread		$thread
	 */
	public function restore(Thread $thread) {
		$this->add($thread, 'restore');
	}
	
	/**
	 * Adds a log entry for thread soft-delete (trash).
	 *
	 * @param	wbb\data\thread\Thread		$thread
	 * @param	string				$reason
	 */
	public function trash(Thread $thread, $reason = '') {
		$this->add($thread, 'trash', array('reason' => $reason));
	}
	
	/**
	 * Adds a log entry for thread marking as undone.
	 *
	 * @param	wbb\data\thread\Thread		$thread
	 */
	public function undone(Thread $thread) {
		$this->add($thread, 'undone');
	}
	
	/**
	 * Adds a log entry for changed labels.
	 * 
	 * @param	Thread			$thread
	 * @param	wcf\data\label\Label	$label
	 */
	public function setLabel(Thread $thread, Label $label) {
		$this->add($thread, 'setLabel', array('label' => $label));
	}
	
	/**
	 * Adds a thread modification log entry.
	 * 
	 * @param	wbb\data\thread\Thread	$thread
	 * @param	string			$action
	 * @param	array			$additionalData
	 */
	public function add(Thread $thread, $action, array $additionalData = array()) {
		parent::_add('com.woltlab.wbb.thread', $thread->threadID, $action, $additionalData);
	}
}
