<?php
namespace wbb\system\menu\page;
use wbb\data\board\Board;
use wbb\data\board\BoardCache;
use wcf\system\database\util\PreparedStatementConditionBuilder;
use wcf\system\language\LanguageFactory;
use wcf\system\menu\page\DefaultPageMenuItemProvider;
use wcf\system\user\storage\UserStorageHandler;
use wcf\system\visitTracker\VisitTracker;
use wcf\system\WCF;

/**
 * Burning Board page menu item provider.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.menu.page
 * @category	Burning Board
 */
class WBBPageMenuItemProvider extends DefaultPageMenuItemProvider {
	/**
	 * number of unread threads.
	 * @var	integer
	 */
	protected $notifications = null;
	
	/**
	 * @see	wcf\system\menu\page\PageMenuItemProvider::getNotifications()
	 */
	public function getNotifications() {
		if ($this->notifications === null) {
			$this->notifications = 0;
			
			if (WCF::getUser()->userID) {
				// load storage data
				UserStorageHandler::getInstance()->loadStorage(array(WCF::getUser()->userID));
				
				// get ids
				$data = UserStorageHandler::getInstance()->getStorage(array(WCF::getUser()->userID), 'wbbUnreadThreads');
				
				// cache does not exist or is outdated
				if ($data[WCF::getUser()->userID] === null) {
					$boardIDs = Board::getAccessibleBoardIDs();
					// removed ignored boards
					foreach ($boardIDs as $key => $boardID) {
						$board = BoardCache::getInstance()->getBoard($boardID);
						if ($board->isIgnored()) {
							unset($boardIDs[$key]);
						}
					}
					
					if (!empty($boardIDs)) {
						$conditionBuilder = new PreparedStatementConditionBuilder();
						$conditionBuilder->add("thread.lastPostTime > ?", array(VisitTracker::getInstance()->getVisitTime('com.woltlab.wbb.thread')));
						$conditionBuilder->add("thread.boardID IN (?)", array($boardIDs));
						$conditionBuilder->add("thread.isDeleted = 0 AND thread.isDisabled = 0 AND thread.movedThreadID IS NULL");
						$conditionBuilder->add("(thread.lastPostTime > tracked_thread_visit.visitTime OR tracked_thread_visit.visitTime IS NULL)");
						$conditionBuilder->add("(thread.lastPostTime > tracked_board_visit.visitTime OR tracked_board_visit.visitTime IS NULL)");
						// apply language filter
						if (LanguageFactory::getInstance()->multilingualismEnabled() && count(WCF::getUser()->getLanguageIDs())) {
							$conditionBuilder->add('(thread.languageID IN (?) OR thread.languageID IS NULL)', array(WCF::getUser()->getLanguageIDs()));
						}
						
						$sql = "SELECT		COUNT(*) AS count
							FROM		wbb".WCF_N."_thread thread
							LEFT JOIN	wcf".WCF_N."_tracked_visit tracked_thread_visit
							ON		(tracked_thread_visit.objectTypeID = ".VisitTracker::getInstance()->getObjectTypeID('com.woltlab.wbb.thread')." AND tracked_thread_visit.objectID = thread.threadID AND tracked_thread_visit.userID = ".WCF::getUser()->userID.")
							LEFT JOIN	wcf".WCF_N."_tracked_visit tracked_board_visit
							ON		(tracked_board_visit.objectTypeID = ".VisitTracker::getInstance()->getObjectTypeID('com.woltlab.wbb.board')." AND tracked_board_visit.objectID = thread.boardID AND tracked_board_visit.userID = ".WCF::getUser()->userID.")
							".$conditionBuilder;
						$statement = WCF::getDB()->prepareStatement($sql);
						$statement->execute($conditionBuilder->getParameters());
						$row = $statement->fetchArray();
						$this->notifications = $row['count'];
					}
					
					// update storage data
					UserStorageHandler::getInstance()->update(WCF::getUser()->userID, 'wbbUnreadThreads', $this->notifications);
				}
				else {
					$this->notifications = $data[WCF::getUser()->userID];
				}
			}
		}
		
		return $this->notifications;
	}
}
