<?php
namespace wbb\system\menu\page;
use wbb\data\board\Board;
use wcf\system\database\util\PreparedStatementConditionBuilder;
use wcf\system\menu\page\DefaultPageMenuItemProvider;
use wcf\system\user\object\watch\UserObjectWatchHandler;
use wcf\system\user\storage\UserStorageHandler;
use wcf\system\visitTracker\VisitTracker;
use wcf\system\WCF;

/**
 * Watched threads page menu item provider.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.menu.page
 * @category	Burning Board
 */
class WatchedThreadsPageMenuItemProvider extends DefaultPageMenuItemProvider {
	/**
	 * number of unread watched threads.
	 * @var	integer
	 */
	protected $notifications = null;
	
	/**
	 * @see	wcf\system\menu\page\IPageMenuItemProvider::isVisible()
	 */
	public function isVisible() {
		return (WCF::getUser()->userID ? true : false);
	}
	
	/**
	 * @see	wcf\system\menu\page\IPageMenuItemProvider::getNotifications()
	 */
	public function getNotifications() {
		if ($this->notifications === null) {
			$this->notifications = 0;
			
			if (WCF::getUser()->userID) {
				// load storage data
				UserStorageHandler::getInstance()->loadStorage(array(WCF::getUser()->userID));
					
				// get ids
				$data = UserStorageHandler::getInstance()->getStorage(array(WCF::getUser()->userID), 'wbbUnreadWatchedThreads');
				
				// cache does not exist or is outdated
				if ($data[WCF::getUser()->userID] === null) {
					$boardIDs = Board::getAccessibleBoardIDs();
					if (!empty($boardIDs)) {
						$objectTypeID = UserObjectWatchHandler::getInstance()->getObjectTypeID('com.woltlab.wbb.thread');
						
						$conditionBuilder = new PreparedStatementConditionBuilder();
						$conditionBuilder->add('user_object_watch.objectTypeID = ?', array($objectTypeID));
						$conditionBuilder->add('user_object_watch.userID = ?', array(WCF::getUser()->userID));
						$conditionBuilder->add('thread.lastPostTime > ?', array(VisitTracker::getInstance()->getVisitTime('com.woltlab.wbb.thread')));
						$conditionBuilder->add('thread.boardID IN (?)', array($boardIDs));
						$conditionBuilder->add('thread.isDeleted = 0 AND thread.isDisabled = 0');
						$conditionBuilder->add('(thread.lastPostTime > tracked_thread_visit.visitTime OR tracked_thread_visit.visitTime IS NULL)');
						$conditionBuilder->add('(thread.lastPostTime > tracked_board_visit.visitTime OR tracked_board_visit.visitTime IS NULL)');
						
						$sql = "SELECT		COUNT(*) AS count
							FROM		wcf".WCF_N."_user_object_watch user_object_watch
							LEFT JOIN	wbb".WCF_N."_thread thread
							ON		(thread.threadID = user_object_watch.objectID)
							LEFT JOIN	wcf".WCF_N."_tracked_visit tracked_thread_visit
							ON		(tracked_thread_visit.objectTypeID = ".VisitTracker::getInstance()->getObjectTypeID('com.woltlab.wbb.thread')." AND tracked_thread_visit.objectID = thread.threadID AND tracked_thread_visit.userID = ".WCF::getUser()->userID.")
							LEFT JOIN	wcf".WCF_N."_tracked_visit tracked_board_visit
							ON		(tracked_board_visit.objectTypeID = ".VisitTracker::getInstance()->getObjectTypeID('com.woltlab.wbb.board')." AND tracked_board_visit.objectID = thread.boardID AND tracked_board_visit.userID = ".WCF::getUser()->userID.")
							".$conditionBuilder;
						$statement = WCF::getDB()->prepareStatement($sql);
						$statement->execute($conditionBuilder->getParameters());
						$row = $statement->fetchArray();
						$this->notifications = $row['count'];
					}
					
					// update storage data
					UserStorageHandler::getInstance()->update(WCF::getUser()->userID, 'wbbUnreadWatchedThreads', $this->notifications);
				}
				else {
					$this->notifications = $data[WCF::getUser()->userID];
				}
			}
		}
		
		return $this->notifications;
	}
}
