<?php
namespace wbb\system\moderation\queue\report;
use wbb\data\post\ViewablePost;
use wbb\system\moderation\queue\AbstractPostModerationQueueHandler;
use wcf\data\moderation\queue\ViewableModerationQueue;
use wcf\system\moderation\queue\report\IModerationQueueReportHandler;
use wcf\system\WCF;

/**
 * An implementation of IModerationQueueReportHandler for forum posts.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.moderation.queue.report
 * @category	Burning Board
 */
class PostModerationQueueReportHandler extends AbstractPostModerationQueueHandler implements IModerationQueueReportHandler {
	/**
	 * @see	wcf\system\moderation\queue\AbstractModerationQueueHandler::$definitionName
	 */
	protected $definitionName = 'com.woltlab.wcf.moderation.report';
	
	/**
	 * @see	wcf\system\moderation\queue\AbstractModerationQueueHandler::$objectType
	 */
	protected $objectType = 'com.woltlab.wbb.post';
	
	/**
	 * @see	wcf\system\moderation\queue\report\IModerationQueueReportHandler::canReport()
	 */
	public function canReport($objectID) {
		if (!$this->isValid($objectID)) {
			return false;
		}
		
		if (!$this->getPost($objectID)->canRead()) {
			return false;
		}
		
		return true;
	}
	
	/**
	 * @see	wcf\system\moderation\queue\report\IModerationQueueReportHandler::getReportedContent()
	 */
	public function getReportedContent(ViewableModerationQueue $queue) {
		WCF::getTPL()->assign(array(
			'post' => new ViewablePost($queue->getAffectedObject())
		));
		
		return WCF::getTPL()->fetch('moderationPost', 'wbb');
	}
	
	/**
	 * @see	wcf\system\moderation\queue\report\IModerationQueueReportHandler::getReportedObject()
	 */
	public function getReportedObject($objectID) {
		if ($this->isValid($objectID)) {
			return $this->getPost($objectID);
		}
		
		return null;
	}
}
