<?php
namespace wbb\system\option;
use wbb\data\board\BoardCache;
use wbb\data\board\RestrictedBoardNodeList;
use wcf\data\option\Option;
use wcf\system\exception\UserInputException;
use wcf\system\option\AbstractOptionType;
use wcf\system\WCF;
use wcf\util\ArrayUtil;

/**
 * Option type implementation for multi select lists.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.option
 * @category	Burning Board
 */
class WBBBoardMultiSelectOptionType extends AbstractOptionType {
	/**
	 * @see	wcf\system\option\IOptionType::getFormElement()
	 */
	public function getFormElement(Option $option, $value) {
		// get searchable boards
		$boardNodeList = new RestrictedBoardNodeList();
		$boardNodeList->readNodeTree();
		
		WCF::getTPL()->assign(array(
			'boardNodeList' => $boardNodeList->getNodeList(),
			'option' => $option,
			'value' => (!is_array($value) ? explode("\n", $value) : $value)
		));
		return WCF::getTPL()->fetch('boardMultiSelectOptionType', 'wbb');
	}
	
	/**
	 * @see	wcf\system\option\IOptionType::validate()
	 */
	public function validate(Option $option, $newValue) {
		if (!is_array($newValue)) $newValue = array();
		$newValue = ArrayUtil::toIntegerArray($newValue);
		
		foreach ($newValue as $boardID) {
			if (BoardCache::getInstance()->getBoard($boardID) === null) {
				throw new UserInputException($option->optionName, 'validationFailed');
			}
		}
	}
	
	/**
	 * @see	wcf\system\option\IOptionType::getData()
	 */
	public function getData(Option $option, $newValue) {
		if (!is_array($newValue)) $newValue = array();
		return implode("\n", ArrayUtil::toIntegerArray($newValue));
	}
}
