<?php
namespace wbb\system\option;
use wbb\data\board\BoardCache;
use wbb\data\board\RestrictedBoardNodeList;
use wcf\data\option\Option;
use wcf\system\exception\UserInputException;
use wcf\system\option\AbstractOptionType;
use wcf\system\WCF;

/**
 * Option type implementation for select lists.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.option
 * @category	Burning Board
 */
class WBBBoardSelectOptionType extends AbstractOptionType {
	/**
	 * @see	wcf\system\option\IOptionType::getFormElement()
	 */
	public function getFormElement(Option $option, $value) {
		// get searchable boards
		$boardNodeList = new RestrictedBoardNodeList();
		$boardNodeList->readNodeTree();
		
		WCF::getTPL()->assign(array(
			'boardNodeList' => $boardNodeList->getNodeList(),
			'option' => $option,
			'value' => $value
		));
		return WCF::getTPL()->fetch('boardSelectOptionType', 'wbb');
	}
	
	/**
	 * @see	wcf\system\option\IOptionType::validate()
	 */
	public function validate(Option $option, $newValue) {
		if (!empty($newValue)) {
			if (BoardCache::getInstance()->getBoard(intval($newValue)) === null) {
				throw new UserInputException($option->optionName, 'validationFailed');
			}
		}
	}
	
	/**
	 * @see	wcf\system\option\IOptionType::getData()
	 */
	public function getData(Option $option, $newValue) {
		return intval($newValue);
	}
}
