<?php
namespace wbb\system\user\activity\event;
use wbb\data\post\PostList;
use wbb\data\thread\ThreadList;
use wcf\system\user\activity\event\IUserActivityEvent;
use wcf\system\SingletonFactory;
use wcf\system\WCF;

/**
 * User activity event implementation for posts.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.user.activity.event
 * @category	Burning Board
 */
class PostUserActivityEvent extends SingletonFactory implements IUserActivityEvent {
	/**
	 * @see	wcf\system\user\activity\event\IUserActivityEvent::prepare()
	 */
	public function prepare(array $events) {
		$objectIDs = array();
		foreach ($events as $event) {
			$objectIDs[] = $event->objectID;
		}
		
		// fetch posts
		$postList = new PostList();
		$postList->getConditionBuilder()->add("post.postID IN (?)", array($objectIDs));
		$postList->readObjects();
		$posts = $postList->getObjects();
		
		// fetch threads
		$threadIDs = $threads = array();
		foreach ($posts as $post) {
			$threadIDs[] = $post->threadID;
		}
		if (!empty($threadIDs)) {
			$threadList = new ThreadList();
			$threadList->getConditionBuilder()->add("thread.threadID IN (?)", array($threadIDs));
			$threadList->readObjects();
			$threads = $threadList->getObjects();
		}
		
		// set message
		foreach ($events as $event) {
			if (isset($posts[$event->objectID])) {
				$post = $posts[$event->objectID];
				$thread = $threads[$post->threadID];
				$post->setThread($thread);
				
				// check permissions
				if (!$post->canRead()) {
					continue;
				}
				$event->setIsAccessible();
				
				// short output
				$text = WCF::getLanguage()->getDynamicVariable('wcf.user.profile.recentActivity.post', array(
					'post' => $post,
					'thread' => $threads[$post->threadID]
				));
				$event->setTitle($text);
				
				// output
				$event->setDescription($post->getExcerpt());
			}
			else {
				$event->setIsOrphaned();
			}
		}
	}
}
