<?php
namespace wbb\system\user\activity\event;
use wbb\data\post\PostList;
use wbb\data\thread\ThreadList;
use wcf\system\user\activity\event\IUserActivityEvent;
use wcf\system\SingletonFactory;
use wcf\system\WCF;

/**
 * User activity event implementation for threads.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.user.activity.event
 * @category	Burning Board
 */
class ThreadUserActivityEvent extends SingletonFactory implements IUserActivityEvent {
	/**
	 * @see	wcf\system\user\activity\event\IUserActivityEvent::prepare()
	 */
	public function prepare(array $events) {
		$objectIDs = array();
		foreach ($events as $event) {
			$objectIDs[] = $event->objectID;
		}
		
		// fetch threads
		$threadList = new ThreadList();
		$threadList->getConditionBuilder()->add("thread.threadID IN (?)", array($objectIDs));
		$threadList->readObjects();
		$threads = $threadList->getObjects();
		
		// fetch first posts
		$postIDs = $posts = array();
		foreach ($threads as $thread) {
			$postIDs[] = $thread->firstPostID;
		}
		if (count($postIDs)) {
			$postList = new PostList();
			$postList->getConditionBuilder()->add("post.postID IN (?)", array($postIDs));
			$postList->readObjects();
			$posts = $postList->getObjects();
		}
				
		// set message
		foreach ($events as $event) {
			if (isset($threads[$event->objectID])) {
				$thread = $threads[$event->objectID];
				
				// validate permissions
				if (!$thread->canRead()) {
					continue;
				}
				$event->setIsAccessible();
				
				// short output
				$text = WCF::getLanguage()->getDynamicVariable('wcf.user.profile.recentActivity.thread', array('thread' => $thread));
				$event->setTitle($text);
				
				if (isset($posts[$thread->firstPostID])) {
					$event->setDescription($posts[$thread->firstPostID]->getExcerpt());
				}
			}
			else {
				$event->setIsOrphaned();
			}
		}
	}
}
