<?php
namespace wbb\system\user\online\location;
use wbb\data\board\Board;
use wbb\data\thread\ThreadList;
use wcf\data\user\online\UserOnline;
use wcf\system\user\online\location\IUserOnlineLocation;
use wcf\system\WCF;

/**
 * Implementation of IUserOnlineLocation for the thread page location.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb
 * @subpackage	system.user.online
 * @category	Burning Board
 */
class ThreadLocation implements IUserOnlineLocation {
	/**
	 * thread ids
	 * @var	array<integer>
	 */
	protected $threadIDs = array();
	
	/**
	 * list of threads
	 * @var	array<wbb\data\thread\Thread>
	 */
	protected $threads = null;
	
	/**
	 * @see	wcf\system\user\online\location\IUserOnlineLocation::cache()
	 */
	public function cache(UserOnline $user) {
		if ($user->objectID) $this->threadIDs[] = $user->objectID;
	}
	
	/**
	 * @see	wcf\system\user\online\location\IUserOnlineLocation::get()
	 */
	public function get(UserOnline $user, $languageVariable = '') {
		if ($this->threads === null) {
			$this->readThreads();
		}
		
		if (!isset($this->threads[$user->objectID])) {
			return '';
		}
		
		return WCF::getLanguage()->getDynamicVariable($languageVariable, array('thread' => $this->threads[$user->objectID]));
	}
	
	/**
	 * Loads the threads.
	 */
	protected function readThreads() {
		$this->threads = array();
		
		if (empty($this->threadIDs)) return;
		$this->threadIDs = array_unique($this->threadIDs);
		$boardIDs = Board::getAccessibleBoardIDs();
		if (empty($boardIDs)) return;
		
		$threadList = new ThreadList();
		$threadList->getConditionBuilder()->add('thread.threadID IN (?)', array($this->threadIDs));
		$threadList->getConditionBuilder()->add('thread.boardID IN (?)', array($boardIDs));
		$threadList->getConditionBuilder()->add('thread.isDeleted = 0 AND thread.isDisabled = 0');
		$threadList->readObjects();
		$this->threads = $threadList->getObjects();
	}
}
